<?php
    global $wp;

    $shop_enabled = get_option('sonax_shop_enabled');
    $theme_location = 'header_menu';
    $nested_menu = [];

    $gmaps_api_key = get_option('sonax_gmaps_api_key');
    
    // check if there is a menu in the the theme-location 'main-menu'

    if (has_nav_menu($theme_location)) {
        // get the menus name from theme-location
        $theme_locations = get_nav_menu_locations();
        $menu_obj = get_term( $theme_locations[$theme_location], 'nav_menu' );
        $menu_name = $menu_obj->name;
    
        // get the menu object
        $items = wp_get_nav_menu_items($menu_name);
    
        // Support up to three levels of nesting by traversing through all items and finding the matching parent
        // Converts the flat navigation array into a nested array of objects with children properties
        foreach ($items as $key => $item) {
            if ($item->menu_item_parent == 0) {
                $item->children = [];
                array_push($nested_menu, $item);
                foreach ($items as $key => $second_level_item) {
                    if ($second_level_item->menu_item_parent == $item->ID) {
                        $second_level_item->children = [];
                        array_push($item->children, $second_level_item);
                        foreach ($items as $key => $third_level_item) {
                            if ($third_level_item->menu_item_parent == $second_level_item->ID) {
                                $third_level_item->children = [];
                                array_push($second_level_item->children, $third_level_item);
                            } 
                        }
                    } 
                }
            } 
        }
    }

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
<link rel="apple-touch-icon" sizes="180x180" href="<?php echo get_template_directory_uri(); ?>/assets/favicons/apple-touch-icon.png">
<link rel="icon" type="image/png" sizes="32x32" href="<?php echo get_template_directory_uri(); ?>/assets/favicons/favicon-32x32.png">
<link rel="icon" type="image/png" sizes="16x16" href="<?php echo get_template_directory_uri(); ?>/assets/favicons/favicon-16x16.png">
<link rel="manifest" href="<?php echo get_template_directory_uri(); ?>/assets/favicons/manifest.json">
<link rel="mask-icon" href="<?php echo get_template_directory_uri(); ?>/assets/favicons/safari-pinned-tab.svg" color="#539aa3">
<meta name="msapplication-TileColor" content="#539aa3">
<meta name="msapplication-TileImage" content="/assets/favicons/mstile-144x144.png">
<meta name="theme-color" content="#ffffff">
<meta name="viewport" content="width=device-width, initial-scale=1">

<?php if ( get_option( 'sonax_font_licensed' ) ) : ?>
    <link rel="stylesheet" crossorigin="" type="text/css" href="https://fonts.sonax.com/assets/style.css">
<?php endif; ?>

<meta name="wp-store-nonce" content="<?php echo wp_create_nonce( 'wc_store_api' ); ?>" >
<?php wp_head(); ?>
<style>
    .snx-page-layout {
        min-height: 100vh;
    }
</style>
<?php if (!empty($gmaps_api_key)) : ?>
    <script>
        window.gmapsApiKey = "<?php echo $gmaps_api_key; ?>";
    </script>
<?php endif; ?>
<!-- See woocommerce/cart/cart.php#23 for details -->
<style>
    .woocommerce-notices-wrapper {
        display: none !important; 
    }
</style>

</head>

<!-- <body class="snx-katana snx-template-a"> -->
<body <?php body_class(); ?> >
    <header class="snx-header snx-header--in-grid" style="z-index: 9999;">
        <div class="snx-header__container">
            <a class="snx-header__logo" href="/" title="SONAX GmbH">
                <img
                    class="snx-header__logo-item"
                    src="<?php echo get_template_directory_uri(); ?>/assets/logo-snx.svg"
                    alt="sonax logo"
                    title="sonax logo"
                />
            </a>

            <nav class="snx-header__meta-navigation">
                <a
                    id="headerSearchCollapseControls"
                    class="snx-header__meta-navigation-item snx-is-collapseToggle <?php if (!is_search()) { echo "collapsed"; }; ?>"
                    data-toggle="collapse"
                    data-target='#headerSearchCollapse'
                    aria-expanded="<?php if (is_search()) { echo "true"; } else { echo "false"; }; ?>"
                    aria-controls="headerSearchCollapse"
                >
                    <svg class="snx-icon snx-search-open-icon" viewBox="0 0 32 32">
                        <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_search"></use>
                    </svg>
                    <svg class="snx-icon snx-search-close-icon" viewBox="0 0 32 32">
                        <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_cross"></use>
                    </svg>
                </a>

                <?php if ($shop_enabled): ?>
                    <a class="snx-header__meta-navigation-item" href="<?php echo wc_get_cart_url(); ?>">
                        <svg class="snx-icon snx-cart-icon" viewBox="0 0 32 32">
                            <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#shopping-cart-line"></use>
                        </svg>
                        <span class="snx-cart-count">
                            <?php
                                $product_count =  WC()->cart->get_cart_contents_count();
    
                                if ($product_count > 0) {
                                    echo $product_count;
                                }
                            ?>
                        </span>
                    </a>
                <?php endif; ?>

                <a id="toggleNavButton" class="snx-header__toggle-nav snx-toggle-offcanvas-js">
                    <svg class="snx-icon" viewBox="0 0 32 32">
                        <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_bars"></use>
                    </svg>
                </a>
            </nav>
        </div>
        <div id="headerSearchCollapse" class="snx-header__search collapse <?php if (is_search()) { echo "show"; }; ?>">
            <div class="snx-header__search-container">
                <div class="snx-header__search-form">
                    <form class="snx-form-search " action="<?php echo home_url( '/' ); ?>" style="margin-block-end: 0;">
                    <button
                        class="snx-btn snx-btn--link snx-btn--icon-left snx-form-search__button"
                    >
                        <svg class="snx-icon" viewBox="0 0 32 32">
                            <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_right"></use>
                        </svg>
                        <span><?php echo __('Search', 'sonax'); ?></span>
                    </button>
                    <input
                        class="snx-form-search__input"
                        placeholder="<?php echo __('What are you looking for?', 'sonax'); ?>"
                        value="<?php echo wp_specialchars($s, 1); ?>"
                        name="s"
                        id="s"
                    />
                    <span class="snx-form-search__icon">
                        <svg class="snx-icon" viewBox="0 0 32 32">
                        <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_search"></use>
                        </svg>
                    </span>
                    </form>
                </div>
            </div>
        </div>
        <div class="snx-offcanvas">
            <div class="snx-offcanvas__header">
                <span id="toggleNavButton" class="snx-btn snx-toggle-offcanvas-js">
                    <svg class="snx-icon" viewBox="0 0 32 32">
                        <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_cross"></use>
                    </svg>
                </span>
            </div>
            <div class="snx-offcanvas__body">
                <nav class="snx-header__mainnavigation">
                    <ul>

                        <?php
                            foreach ($nested_menu as $key => $item) {
                                $href = $item->url;
                                $label = $item->title;

                                echo "<li>";

                                if (!empty($item->children)) {
                                    /* Nav toggle and label */
                                    echo "<div class='snx-nav-item'>";
                                    echo $label;
                                    echo "<div class='snx-header__mainnavigation__dropdown-toggle'>";
                                    echo "<svg class='snx-icon' viewBox='0 0 32 32'>";
                                    echo "<use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_plus'></use>";
                                    echo "</svg>";
                                    echo "<svg class='snx-icon' viewBox='0 0 32 32'>";
                                    echo "<use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_minus'></use>";
                                    echo "</svg>";
                                    echo "</div>";
                                    echo "</div>";

                                    /* Nav Body */
                                    echo "<div class='snx-header__mainnavigation__dropdown snx-clearfix'>";
                                    echo "<ul>";

                                    foreach($item->children as $second_level_item) {
                                        $href = $second_level_item->url;
                                        $label = $second_level_item->title;

                                        echo "<li>";
                                        if (!empty($second_level_item->children)) {
                                            /* Nav toggle and label */
                                            echo "<div class='snx-nav-item'>";
                                            echo "<a href='$href'>";
                                            echo $label;
                                            echo "</a>";
                                            echo "<div class='snx-header__mainnavigation__dropdown-toggle'>";
                                            echo "<svg class='snx-icon' viewBox='0 0 32 32'>";
                                            echo "<use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_plus'></use>";
                                            echo "</svg>";
                                            echo "<svg class='snx-icon' viewBox='0 0 32 32'>";
                                            echo "<use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_minus'></use>";
                                            echo "</svg>";
                                            echo "</div>";
                                            echo "</div>";

                                            /* Nav Body */
                                            echo "<div class='snx-header__mainnavigation__dropdown snx-clearfix' style='border-left: none;'>";
                                            echo "<ul>";

                                            foreach ($second_level_item->children as $third_level_item) {
                                                $href = $third_level_item->url;
                                                $label = $third_level_item->title;

                                                echo "<li>";
                                                echo "<a class='snx-nav-item' href='$href' title='$label'>$label</a>";
                                                echo "</li>";
                                            }

                                            echo "</ul>";
                                            echo "</div>";
                                        } else {
                                            echo "<a class='snx-nav-item' href='$href' title='$label'>$label</a>";
                                        }
                                        echo "</li>";

                                    }

                                    echo "</ul>";
                                    echo "</div>";

                                } else {
                                    echo "<a class='snx-nav-item' href='$href' title='$label'>$label</a>";
                                }

                                echo "</li>";
                            }
                        ?>

                    </ul>
                </nav>
            </div>
        </div>
    </header>
    <?php if (function_exists('nav_breadcrumb') && !is_search()) nav_breadcrumb(); ?>
    <div class="snx-page-layout">
        
