<?php
/**
 * 
 * Register custom gutenberg blocks and configure core blocks
 * 
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once('image-url-to-id.php');


function render_php($path,array $render_php_args) {
    ob_start();
    include_once $path;
    $var=ob_get_contents(); 
    ob_end_clean();
    return $var;
}

function debug_to_console($data, $context = 'Debug in Console') {
    $output  = 'console.info(\'' . $context . ':\');';
    $output .= 'console.log(' . json_encode($data) . ');';
    $output  = sprintf('<script>%s</script>', $output);

    return $output;
}

/* #m */

function sonax_blocks_application_guide_render_callback ($block_attributes, $content) {

  $layout_class = $block_attributes['layout'];
  $title = $block_attributes['title'];

  $markup = "<section class='snx-page-section'>";

  if (isset($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";

  $markup .= "<div class='snx-application-guide $layout_class'>";
  $markup .= $content;
  $markup .= "</div>";

  $markup .= "</div>";
  $markup .= "</section>";

  return $markup;
}

function sonax_blocks_application_guide_item_render_callback($block_attributes, $content) {
  $title = $block_attributes['title'];
  $image = false;

  if (!empty($block_attributes['imageUrl'])) {
    $image = $block_attributes['imageUrl'];
    $fallback_img_src = $image['full']['url'];
  }

  $markup = "<figure class='snx-application-guide__item'>";



  if ($image) {
    $markup .= "<picture class='snx-application-guide__item-image'>";

    if (isset($image['375x250']) && isset($image['750x500'])) {
      $url1x = $image['375x250']['url'];
      $url2x = $image['750x500']['url'];

      $markup .= "<source media='(max-width: 479px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['375x250'])) {
      $markup .= "<source media='(max-width: 479px)' srcset='$url1x' />";
    }

    if (isset($image['480x320']) && isset($image['960x640'])) {
      $url1x = $image['480x320']['url'];
      $url2x = $image['960x640']['url'];

      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['480x320'])) {
      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$url1x' />";
    }

    if (isset($image['480x320']) && isset($image['960x640'])) {
      $url1x = $image['480x320']['url'];
      $url2x = $image['960x640']['url'];

      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['480x320'])) {
      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$url1x' />";
    }

    if (isset($image['480x320']) && isset($image['960x640'])) {
      $url1x = $image['480x320']['url'];
      $url2x = $image['960x640']['url'];

      $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['480x320'])) {
      $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$url1x' />";
    }

    if (isset($image['600x400']) && isset($image['1290x860'])) {
      $url1x = $image['600x400']['url'];
      $url2x = $image['1290x860']['url'];

      $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='$url1x, $url2x 2x' />";
      $markup .= "<source media='(min-width: 1400px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['600x400'])) {
      $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='$url1x' />";
      $markup .= "<source media='(min-width: 1400px)' srcset='$url1x' />";
    }

    $markup .= "<img src='$fallback_img_src' />";

    $markup .= "</picture>";
  }	

  $markup .= "<figcaption class='snx-application-guide__item-description'>";
  $markup .= "<h3>$title</h3>";
  $markup .= $content;
  $markup .= "</figcaption>";
  $markup .= "</figure>";

  return $markup;	
}

function sonax_blocks_insertions_render_callback($block_attributes, $content) {
  $title = $block_attributes['title'];
  $image_path = get_template_directory_uri() . "/assets/lightbulb.svg" ;

  $markup = "<section class='snx-page-section'>";
  $markup .= "<div class='snx-page-section__body'>";

  $markup .= "<div class='snx-insertion  snx-insertion--is-block'>";
  $markup .= "<div class='snx-insertion__asset-container'>";
  $markup .= "<div class='snx-insertion__asset'>";
  $markup .= "<picture><img src='$image_path' alt='lightbulb' /></picture>";
  $markup .= "</div>";
  $markup .= "</div>";
  $markup .= "<div class='snx-insertion__body'>";
  $markup .= "<p class='snx-insertion__lead'><strong>$title</strong></p>";
  $markup .= "<div class='snx-insertion__description'>";
  $markup .= $content;
  $markup .= "</div>";
  $markup .= "</div>";
  $markup .= "</div>";

  $markup .= "</div>";
  $markup .= "</section>";

  return $markup;
}

function sonax_blocks_locations_render_callback($block_attributes, $content) {
  if (isset($block_attributes['title'])) {
    $title = $block_attributes['title'];
  }

  $lat = $block_attributes['lat'];
  $lng = $block_attributes['lng'];

  $markup = "<section class='snx-page-section'>";

  if (!empty($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";
  $markup .= "<div class='snx-rich-text'>";

  $markup .= "<script>window.gmapsDefaultCenter = { lat: $lat, lng: $lng }</script>";

  $markup .= "<div class='snx-map-wrapper'>";

  $markup .= render_php(get_template_directory() . '/inc/locations-frontend.php', array('map_search_block' => true));

  $markup .= "</div>";
  $markup .= "</div>";
  $markup .= "</div>";

  $markup .= "</section>";

  return $markup;
};

function sonax_blocks_quotes_render_callback($block_attributes, $content) {
  $title = $block_attributes['title'];
  $image_path = get_template_directory_uri() . "/assets/lightbulb.svg" ;
  $quote_citation = $block_attributes['citation'];

  $image = false;

  if (!empty($block_attributes['imageUrl'])) {
    $image = $block_attributes['imageUrl'];
    $fallback_img_src = $image['full']['url'];
  }

  $markup = "<section class='snx-page-section'>";
  $markup .= "<div class='snx-page-section__body'>";

  $markup .= "<div class='snx-insertion  snx-insertion--is-block'>";


  if ($image) {

    $markup .= "<div class='snx-insertion__asset-container'>";
    $markup .= "<div class='snx-insertion__asset'>";
    $markup .= "<picture>";

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(max-width: 479px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(max-width: 479px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='$url1x, $url2x 2x' />";
      $markup .= "<source media='(min-width: 1400px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='$url1x' />";
      $markup .= "<source media='(min-width: 1400px)' srcset='$url1x' />";
    }

    $markup .= "<img src='$fallback_img_src' />";

    $markup .= "</picture>";
    $markup .= "</div>";
    $markup .= "</div>";

  }	


  $markup .= "<div class='snx-insertion__body'>";
  $markup .= "<p class='snx-insertion__lead'><strong>$title</strong></p>";
  $markup .= "<div class='snx-insertion__description'>";
  $markup .= $content;

  if ($quote_citation) {
    $markup .= "<br /><cite>$quote_citation</cite>";
  }

  $markup .= "</div>";
  $markup .= "</div>";
  $markup .= "</div>";

  $markup .= "</div>";
  $markup .= "</section>";

  return $markup;
}

function sonax_blocks_person_list_item_render_callback($block_attributes) {
  $person_id = $block_attributes['person']['id'];
  $person = get_post($person_id);

  $name = get_the_title($person_id);
  $image_array =  get_field('image', $person_id);
  $image = $image_array['sizes'];
  $fallback_img_src = $image['medium'];

  $title = get_field('title', $person_id);
  $email = get_field('email', $person_id);
  $phone = get_field('phone', $person_id);


  $markup = "<div class='snx-person-card snx-person-card--is-block'>";

  $markup .= "<div class='snx-person-card__image'>";

  $markup .= "<picture>";

  if ($image) {
    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210'];
      $url2x = $image['746x420'];

      $markup .= "<source media='(max-width: 479px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210'];
      $markup .= "<source media='(max-width: 479px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210'];
      $url2x = $image['746x420'];

      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210'];
      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210'];
      $url2x = $image['746x420'];

      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210'];
      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210'];
      $url2x = $image['746x420'];

      $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210'];
      $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210'];
      $url2x = $image['746x420'];

      $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='$url1x, $url2x 2x' />";
      $markup .= "<source media='(min-width: 1400px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['746x420'])) {
      $url1x = $image['373x210'];
      $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='$url1x' />";
      $markup .= "<source media='(min-width: 1400px)' srcset='$url1x' />";
    }

    $markup .= "<img src='$fallback_img_src' />";

  }	

  $markup .= "</picture>";



  $markup .= "</div>";

  $markup .= "<div class='snx-person-card__body'>";

  $markup .= "<h4 class='snx-font-subtitle-03'>$name</h4>";
  $markup .= "<span>$title</span>";

  if ($phone) {
    $markup .= "<div class='snx-spacer--mt-10'>";
    $markup .= "<svg class='snx-icon' viewBox='0 0 32 32'><use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#phone-receiver'></use></svg>";
    $markup .= $phone;
    $markup .= "</div>";
  }

  if ($email) {
    $markup .= "<div class='snx-spacer--mt-10'>";
    $markup .= "<svg class='snx-icon' viewBox='0 0 32 32'><use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#black-back-closed-envelope-shape'></use></svg>";
    $markup .= $email;
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-spacer--mt-10'>";
  $markup .= "<div class='snx-button-group'>";

  if ($phone) {
    $markup .= "<a class='snx-btn snx-btn--default snx-btn--icon-left' href='tel:$phone'>";
    $markup .= "<svg class='snx-icon' viewBox='0 0 32 32'><use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#phone-receiver'></use></svg>";
    $markup .= "<span>";
    $markup .= __('Phone', 'sonax');
    $markup .= "</span>";
    $markup .= "</a>";
  }

  if ($email) {
    $markup .= "<a class='snx-btn snx-btn--default snx-btn--icon-left' href='mailto:$email'>";
    $markup .= "<svg class='snx-icon' viewBox='0 0 32 32'><use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#black-back-closed-envelope-shape'></use></svg>";
    $markup .= "<span>";
    $markup .= __('E-Mail', 'sonax');
    $markup .= "</span>";
    $markup .= "</a>";
  }

  $markup .= "</div>";
  $markup .= "</div>";

  $markup .= "</div>";

  $markup .= "</div>";

  return $markup;
}

function sonax_blocks_person_list_render_callback($block_attributes, $content) {
  if (isset($block_attributes['title'])) {
    $title = $block_attributes['title'];
  }

  $listing_classnames = "snx-element-listing";

  if (isset($block_attributes['personCount']) && $block_attributes['personCount'] < 2) {
    $listing_classnames .= " snx-element-listing--col-1";
  }

  $markup = "<section class='snx-page-section'>";
  if (!empty($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";

  $markup .= "<div class='$listing_classnames'>$content</div>";

  $markup .= "</div>";

  $markup .= "</section>";

  return $markup;
};

function sonax_blocks_card_row_render_callback($block_attributes, $content) {
  if (isset($block_attributes['title'])) {
    $title = $block_attributes['title'];
  }

  $markup = "<section class='snx-page-section'>";
  if (!empty($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";
  $markup .= "<div class='snx-element-listing snx-element-listing--col-3'>$content</div>";

  $markup .= "</div>";

  $markup .= "</section>";

  return $markup;
}

function sonax_blocks_card_render_callback($block_attributes) {
  $headline = $block_attributes['headline'];
  $text = $block_attributes['text'];
  $post_link = $block_attributes['postLink'];
  $image = false;

  if (!empty($block_attributes['imageUrl'])) {
    $image = $block_attributes['imageUrl'];
    $fallback_img_src = $image['full']['url'];
  }


  $markup = "<div class='snx-card'>";

  if (!empty($post_link)) {
    $markup .= "<a href='$post_link' class='snx-card__image'>";
  } else {
    $markup .= "<div class='snx-card__image'>";
  }

  $markup .= "<picture>";

  if ($image) {
    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(max-width: 479px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(max-width: 479px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['373x210'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$url1x' />";
    }

    if (isset($image['373x210']) && isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $url2x = $image['746x420']['url'];

      $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='$url1x, $url2x 2x' />";
      $markup .= "<source media='(min-width: 1400px)' srcset='$url1x, $url2x 2x' />";
    } else if (isset($image['746x420'])) {
      $url1x = $image['373x210']['url'];
      $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='$url1x' />";
      $markup .= "<source media='(min-width: 1400px)' srcset='$url1x' />";
    }

    $markup .= "<img src='$fallback_img_src' />";

  }	

  $markup .= "</picture>";

  if (!empty($post_link)) {
    $markup .= "</a>";
  } else {
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-card__body'>";


  if (!empty($post_link)) {
    $markup .= "<a href='$post_link'>";
  }

  $markup .= "<h2 class='snx-font-subtitle-02'>$headline</h2>";

  if (!empty($post_link)) {
    $markup .= "</a>";
  }

  $markup .= "<p >$text</p>";

  $markup .= "</div>";
  $markup .= "</div>";

  return $markup;
}

function sonax_blocks_accordion_render_callback($block_attributes, $content) {
  if (isset($block_attributes['title'])) {
    $title = $block_attributes['title'];
  }

  $markup = "<section class='snx-page-section'>";
  if (!empty($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";

  $markup .= "<div class='snx-accordion snx-accordion--is-block'>$content</div>";

  $markup .= "</div>";

  $markup .= "</section>";

  return $markup;
}

function sonax_blocks_accordion_item_render_callback($block_attributes, $content, $test) {
  // For some reason, ids for accordion items have to start with "accordionToggle-", plain ids dont work
  $uniqid = "accordionToggle-" . uniqid();

  $title = $block_attributes['title'];
  $subtitle = $block_attributes['subtitle'];

  $markup = "<div class='snx-accordion__item'>";

  $markup .= "<div class='snx-accordion__item-header' aria-expanded='false' data-toggle='collapse' data-target='#$uniqid'>";


  $markup .= "<div class='snx-accordion__item-header-text'>";

  $markup .= "<h4 class='snx-accordion__item-header-title'>$title</h4>";

  if ($subtitle) {
    $markup .= "<p class='snx-accordion__item-header-subtitle'>$subtitle</p>";
  }


  $markup .= "</div>";


  $markup .= "<div class='snx-accordion__item-header-toggle'>";
  $markup .= "<a href='#$uniqid' class='snx-btn snx-btn--link' aria-expanded='false' data-toggle='collapse' data-target='#$uniqid' >";

  $markup .= "<svg class='snx-icon snx-icon-collapsed' viewBox='0 0 32 32'><use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_plus'></use></svg>";
  $markup .= "<svg class='snx-icon snx-icon-opened' viewBox='0 0 32 32'><use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_minus'></use></svg>";

  $markup .= "<span class='snx-text-collapsed'>";
  $markup .= __('show details', 'sonax');
  $markup .= "</span>";

  $markup .= "<span class='snx-text-opened'>";
  $markup .= __('hide details', 'sonax');
  $markup .= "</span>";

  $markup .= "</a>";
  $markup .= "</div>";


  $markup .= "</div>";


  $markup .= "<div class='collapse' id='$uniqid'>";
  $markup .= "<div class='snx-accordion__item-body'>";

  $markup .= $content;

  $markup .= "</div>";
  $markup .= "</div>";


  $markup .= "</div>";

  return $markup;
}

function sonax_blocks_informal_teaser_row_render_callback($block_attributes, $content) {
  if (isset($block_attributes['title'])) {
    $title = $block_attributes['title'];
  }

  $markup = "<section class='snx-page-section'>";
  if (!empty($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";

  $markup .= "<div class='snx-element-listing'>$content</div>";

  $markup .= "</div>";

  $markup .= "</section>";

  return $markup;
}

function sonax_blocks_informal_teaser_render_callback($block_attributes) {
  $headline = $block_attributes['headline'];
  $cta_label = $block_attributes['ctaLabel'];
  $text = $block_attributes['text'] ?? '';
  $post_link = $block_attributes['postLink'];
  $post_link_new_tab = $block_attributes['postLinkNewTab'];
  $image = $block_attributes['imageUrl'];

  $teaser_classnames = "snx-teaser-informal snx-teaser-informal--is-block";
  $teaser_button_classnames = "snx-btn snx-btn--link snx-btn--icon-left";

  $markup = "<div class='$teaser_classnames'>";

  if (!empty($post_link)) {
    $link_target = '_self';

    if ($post_link_new_tab) {
      $link_target = '_blank';
    }

    $markup .= "<a class='snx-teaser-informal__image-container' href='$post_link' target='$link_target'>";
  } else {
    $markup .= "<div class='snx-teaser-informal__image-container'>";
  }

  $markup .= "<picture>";

  $fallback_img_src = $image['full']['url'];
  $image_id = image_url_to_id($fallback_img_src);

  $urlTeaserImageBrpAll = wp_get_attachment_image_src($image_id, '480x480');

  if ($urlTeaserImageBrpAll) {
    $markup .= "<source media='(min-width: 0px)' srcset='$urlTeaserImageBrpAll[0]' />";
  }

  $markup .= "<img src='$fallback_img_src' />";
  $markup .= "</picture>";

  if (!empty($post_link)) {
    $markup .= "</a>";
  } else {
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-teaser-informal__body'>";
  $markup .= "<h4 class='snx-teaser-informal__heading'>";

  if (!empty($post_link)) {
    $link_target = '_self';

    if ($post_link_new_tab) {
      $link_target = '_blank';
    }

    $markup .= "<a class='snx-teaser-informal-link' href='$post_link' target='$link_target'>$headline</a>";
  } else {
    $markup .= "<span class='snx-teaser-informal-link'>$headline</span>";
  }

  $markup .= "</h4>";

  $markup .= "<p class='snx-teaser-informal__copy'>$text</p>";

  if (!empty($cta_label)) {

    if (!empty($post_link)) {

      $link_target = '_self';

      if ($post_link_new_tab) {
        $link_target = '_blank';
      }

      $markup .= "<a class='$teaser_button_classnames' href='$post_link' target='$link_target'><svg class='snx-icon' viewBox='0 0 32 32'><use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_chevron_right'></use></svg><span>$cta_label</span></a>";
    } else {
      $markup .= "<button class='$teaser_button_classnames'><svg class='snx-icon' viewBox='0 0 32 32'><use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_chevron_right'></use></svg><span>$cta_label</span></button>";
    }
  }
  $markup .= "</div>";  

  $markup .= "</div>";

  return $markup;
}

function sonax_blocks_teaser_row_render_callback($block_attributes, $content) {
  if (isset($block_attributes['title'])) {
    $title = $block_attributes['title'];
  }

  $element_listing_layout_classname = '';

  if (isset($block_attributes['layout'])) {
    $element_listing_layout_classname = $block_attributes['layout'];
  }

  $markup = "<section class='snx-page-section'>";
  if (!empty($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";

  $markup .= "<div class='snx-element-listing $element_listing_layout_classname'>$content</div>";

  $markup .= "</div>";

  $markup .= "</section>";

  return $markup;
}

function sonax_blocks_teaser_render_callback($block_attributes) {
  $headline = $block_attributes['headline'];
  $cta_label = $block_attributes['ctaLabel'];
  $invert = $block_attributes['invert'];
  $text = $block_attributes['text'] ?? '';
  $post_link = $block_attributes['postLink'];
  $post_link_new_tab = $block_attributes['postLinkNewTab'];
  $image = $block_attributes['imageUrl'];
  $cover = $block_attributes['cover'];
  $show_featured_image = $block_attributes['showFeaturedImage'];

  $teaser_classnames = "snx-teaser-promo";
  $teaser_button_classnames = "snx-btn snx-btn--link";


  if ($invert && !$cover) {
    $teaser_classnames .= " snx-teaser-promo--is-invert";
    $teaser_button_classnames .= " snx-btn--invert";
  }

  if ($cover) {
    $teaser_classnames .= " snx-teaser-promo--is-cover";
    $teaser_button_classnames .= " snx-btn--invert";
  }

  if ($show_featured_image && !$cover) {
    $teaser_classnames .= " snx-teaser-promo--has-featured-image";
  }

  if (!empty($post_link)) {

    $link_target = '_self';

    if ($post_link_new_tab) {
      $link_target = '_blank';
    }

    $markup = "<a class='$teaser_classnames' href='$post_link' target='$link_target'>";
  } else {
    $markup = "<div class='$teaser_classnames'>";
  }

  $markup .= "<div class='snx-teaser-promo__bg-image'>";
  $markup .= "<picture>";

  $fallback_img_src = $image['full']['url'];
  $image_id = image_url_to_id($fallback_img_src);

  $urlTeaserImageBrp0 = wp_get_attachment_image_src($image_id, '480xAUTO');
  $urlTeaserImageBrp1 = wp_get_attachment_image_src($image_id, '767xAUTO');
  $urlTeaserImageBrp2 = wp_get_attachment_image_src($image_id, '480xAUTO');
  $urlTeaserImageBrp3 = wp_get_attachment_image_src($image_id, '600xAUTO');

  if ($urlTeaserImageBrp0) {
    $markup .= "<source media='(max-width: 479px)' srcset='$urlTeaserImageBrp0[0]' />";
  }

  if ($urlTeaserImageBrp1) {
    $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$urlTeaserImageBrp0[0]' />";
  }

  if ($urlTeaserImageBrp1) {
    $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$urlTeaserImageBrp1[0]' />";
  }

  if ($urlTeaserImageBrp3) {
    $markup .= "<source media='(min-width: 992px)' srcset='$urlTeaserImageBrp3[0]' />";
  }

  $markup .= "<img src='$fallback_img_src' />";
  $markup .= "</picture>";
  $markup .= "</div>";

  $markup .= "<div class='snx-teaser-promo__body'>";
  $markup .= "<div class='snx-teaser-promo__headline'>$headline</div>";

  if (!$cover) {
    $markup .= "<p class='snx-teaser-promo__description'>$text</p>";
  }

  if (!empty($cta_label)) {
    $markup .= "<button class='$teaser_button_classnames' href='#'><svg class='snx-icon' viewBox='0 0 32 32'><use xlink:href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_chevron_right'></use></svg><span>$cta_label</span></button>";
  }
  $markup .= "</div>";

  if ($show_featured_image && !$cover) {

    $featured_image = $block_attributes['featuredImageUrl'];
    $fallback_featured_img_src = $featured_image['full']['url'];
    $featured_image_id = image_url_to_id($fallback_featured_img_src);

    $markup .= "<div class='snx-teaser-promo__featured-image'>";
    $markup .= "<picture>";

    $urlFeaturedImageBrp0 = wp_get_attachment_image_src($featured_image_id, 'AUTOx330');
    $urlFeaturedImageBrp1 = wp_get_attachment_image_src($featured_image_id, 'AUTOx240');
    $urlFeaturedImageBrp2 = wp_get_attachment_image_src($featured_image_id, 'AUTOx300');
    $urlFeaturedImageBrp3 = wp_get_attachment_image_src($featured_image_id, 'AUTOx350');
    $urlFeaturedImageBrp4 = wp_get_attachment_image_src($featured_image_id, 'AUTOx700');

    if ($urlFeaturedImageBrp0) {
      $markup .= "<source media='(max-width: 479px)' srcset='$urlFeaturedImageBrp0[0]' />";
    }

    if ($urlFeaturedImageBrp1) {
      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$urlFeaturedImageBrp1[0]' />";
    }

    if ($urlFeaturedImageBrp2) {
      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$urlFeaturedImageBrp2[0]' />";
    }

    if ($urlFeaturedImageBrp3) {
      $markup .= "<source media='(min-width: 992x) and (max-width: 1199px)' srcset='$urlFeaturedImageBrp3[0]' />";
    }

    if ($urlFeaturedImageBrp4) {
      $markup .= "<source media='(min-width: 1200px)' srcset='$urlFeaturedImageBrp4[0]' />";
    }

    $markup .= "<img src='$fallback_img_src' />";
    $markup .= "</picture>";
    $markup .= "</div>";
  }  


  if (!empty($post_link)) {
    $markup .= "</a>";
  } else {
    $markup .= "</div>";
  }


  return $markup;
}

function sonax_blocks_stage_render_callback($block_attributes) {
  $invert = $block_attributes['invert'];
  $stage_img = $block_attributes['stageImageUrl'];
  $show_featured_image = $block_attributes['showFeaturedImage'];
  $headline = $block_attributes['headline'];
  $show_cta = $block_attributes['showCta'];
  $cta_label = $block_attributes['ctaLabel'];
  $post_link = $block_attributes['postLink'];
  $post_link_new_tab = $block_attributes['postLinkNewTab'];

  $stage_classnames = "snx-stage snx-stage--in-grid";

  if ($invert) {
    $stage_classnames .= " snx-stage--is-invert";
  }


  $markup = "<div class='$stage_classnames'>";

  $markup .= "<div class='snx-stage__bg-image'>";
  $markup .= "<picture>";

  $fallback_img_src = $stage_img['full']['url'];
  $image_id = image_url_to_id($fallback_img_src);

  $urlStageImageBrp0 = wp_get_attachment_image_src($image_id, '480x480');
  $urlStageImageBrp1 = wp_get_attachment_image_src($image_id, '768x512');
  $urlStageImageBrp2 = wp_get_attachment_image_src($image_id, '992x426');
  $urlStageImageBrp3 = wp_get_attachment_image_src($image_id, '1200x515');
  $urlStageImageBrp4 = wp_get_attachment_image_src($image_id, '1920x823');

  if ($urlStageImageBrp0) {
    $markup .= "<source media='(max-width: 479px)' srcset='$urlStageImageBrp0[0]' />";
  }

  if ($urlStageImageBrp1) {
    $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$urlStageImageBrp0[0]' />";
  }

  if ($urlStageImageBrp1) {
    $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$urlStageImageBrp1[0]' />";
  }

  if ($urlStageImageBrp3) {
    $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$urlStageImageBrp3[0]' />";
  }

  if ($urlStageImageBrp4) {
    $markup .= "<source media='(min-width: 1200px)' srcset='$urlStageImageBrp4[0]' />";
  }

  $markup .= "<img src='$fallback_img_src' />";
  $markup .= "</picture>";
  $markup .= "</div>";

  $markup .= "<div class='snx-stage__body'>";
  $markup .= "<h1 class='snx-stage__headline'>$headline</h1>";

  if ($show_cta) {
    if ($post_link_new_tab) {
      $markup .= "<a class='snx-btn snx-btn--primary' href='$post_link' target='_blank' >";
    } else {
      $markup .= "<a class='snx-btn snx-btn--primary' href='$post_link' >";
    }

    $markup .= " <svg class='snx-icon' viewBox='0 0 32 32'><use href='/wp-content/themes/sonax-theme/assets/sprite.svg#snx_chevron_right'></use></svg>";
    $markup .= "<span>$cta_label</span>";
    $markup .= "</a>";
  }


  $markup .= "</div>";

  if ($show_featured_image && isset($block_attributes['featuredImageUrl'])) {

    $featured_image = $block_attributes['featuredImageUrl'];
    $fallback_featured_img_src = $featured_image['full']['url'];
    $featured_image_id = image_url_to_id($fallback_featured_img_src);

    $markup .= "<div class='snx-stage__featured-image'>";
    $markup .= "<picture>";

    $urlFeaturedImageBrp0 = wp_get_attachment_image_src($featured_image_id, 'AUTOx330');
    $urlFeaturedImageBrp1 = wp_get_attachment_image_src($featured_image_id, 'AUTOx240');
    $urlFeaturedImageBrp2 = wp_get_attachment_image_src($featured_image_id, 'AUTOx300');
    $urlFeaturedImageBrp3 = wp_get_attachment_image_src($featured_image_id, 'AUTOx350');
    $urlFeaturedImageBrp4 = wp_get_attachment_image_src($featured_image_id, 'AUTOx700');

    if ($urlFeaturedImageBrp0) {
      $markup .= "<source media='(max-width: 479px)' srcset='$urlFeaturedImageBrp0[0]' />";
    }

    if ($urlFeaturedImageBrp1) {
      $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$urlFeaturedImageBrp1[0]' />";
    }

    if ($urlFeaturedImageBrp2) {
      $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$urlFeaturedImageBrp2[0]' />";
    }

    if ($urlFeaturedImageBrp3) {
      $markup .= "<source media='(min-width: 992x) and (max-width: 1199px)' srcset='$urlFeaturedImageBrp3[0]' />";
    }

    if ($urlFeaturedImageBrp4) {
      $markup .= "<source media='(min-width: 1200px)' srcset='$urlFeaturedImageBrp4[0]' />";
    }

    $markup .= "<img src='$fallback_featured_img_src' />";
    $markup .= "</picture>";
    $markup .= "</div>";
  }

  $markup .= "</div>";

  return $markup;
}

function sonax_blocks_image_gallery_item_render_callback($block_attributes) {
  $image_url = $block_attributes['imageUrl']['full']['url'];
  $caption = wp_get_attachment_caption($block_attributes['id']);

  $markup = "<div class='snx-image-gallery__item'>";
  $markup .= "<figure>";
  $markup .= "<div class='snx-image-gallery__item-image-wrapper'>";
  $markup .= "<picture class=''>";
  $markup .= "<img src='$image_url'>";
  $markup .= "</picture>";
  $markup .= "</div>";
  if ($caption) {
    $markup .= "<figcaption>$caption</figcaption>";
  }
  $markup .= "</figure>";
  $markup .= "</div>";

  return $markup;
}

function sonax_blocks_image_gallery_render_callback($block_attributes, $content) {
  $title = $block_attributes['title'];
  $inner_blocks = $block_attributes['innerBlocks'];

  $markup = "<section class='snx-page-section'>";

  if (isset($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }


  /* open section body */
  $markup .= "<div class='snx-page-section__body'>";

  /* open image gallery */
  $markup .= "<div class='snx-image-gallery'>";

  /* render main slider with sub blocks */
  $markup .= "<div class='snx-image-gallery__images snx-slider snx-slider--slider-image-gallery'>";
  $markup .= "<div class='snx-slider__track-wrapper' data-glide-el='track'>";
  $markup .= "<div class='snx-slider__track'>";
  $markup .= $content;
  $markup .= "</div>";
  $markup .= "</div>";
  $markup .= "</div>";


  /* render slider navigation */
  $markup .= "<div class='snx-image-gallery__nav snx-slider snx-slider--slider-image-gallery-nav'>";
  $markup .= "<div class='snx-slider__container' data-glide-el='controls'>";
  $markup .= "<div class='snx-slider__track-wrapper' data-glide-el='track'>";
  $markup .= "<div class='snx-slider__track'>";


  /* render nav items from array of inner blocks */
  foreach ($inner_blocks as $index=>$gallery_item) {

    $image_url = $gallery_item['attributes']['imageUrl']['full']['url'];

    $markup .=  "<div class='snx-image-gallery__item' data-image-gallery-index='$index'>";
    $markup .=  "<figure>";
    $markup .=  "<div class='snx-image-gallery__item-image-wrapper'>";
    $markup .=  "<picture class=''>";
    $markup .=  "<img src='$image_url' alt='SONAX Stand Motorworld Classic 2018'>";
    $markup .=  "</picture>";
    $markup .=  "</div>";
    $markup .=  "</figure>";
    $markup .=  "</div>";
  }
  
  $markup .= "</div>";
  $markup .= "</div>";

  $markup .= "<button class='slick-next slick-arrow' aria-label='Next' type='button' aria-disabled='false' data-glide-dir='>'>Next</button>";
  $markup .= "<button class='slick-prev slick-arrow' aria-label='Previous' type='button' aria-disabled='true' data-glide-dir='<'>Previous</button>";

  $markup .= "</div>";
  $markup .= "</div>";

  /* close image gallery */
  $markup .= "</div>";

  /* close section body */
  $markup .= "</div>";
  $markup .= "</section>";

  return $markup;
};


function sonax_blocks_product_slider_render_callback($block_attributes, $content) {
  $title = $block_attributes['headline'];

  /* hack to get count of slides from html content (thx wordpress) */
  $slide_count = substr_count($content, "class='snx-slider__slide'");

  $markup = "<section class='snx-page-section'>";

  if (isset($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";

  $markup .= "<div class='snx-slider snx-slider--slider-product'>";
  $markup .= "<div class='snx-slider__body'>";

  $markup .= "<div class='snx-slider__container' data-glide-el='controls'>";
  $markup .= "<div class='snx-slider__track-wrapper' data-glide-el='track'>";
  $markup .= "<div class='snx-slider__track'>";
  $markup .= $content;
  $markup .= "</div>";
  $markup .= "</div>";

  $markup .= "<ul class='slick-dots' data-glide-el='controls[nav]'>";
  for ($i = 0; $i < $slide_count; $i++) {
    $markup .= "<li data-glide-dir='=$i'><button type='button'>$i</button></li>";  
  }
  $markup .= "</ul>";

  $markup .= "<button class='slick-next slick-arrow' aria-label='Next' type='button' aria-disabled='false' data-glide-dir='>'>Next</button>";
  $markup .= "<button class='slick-prev slick-arrow' aria-label='Previous' type='button' aria-disabled='true' data-glide-dir='<'>Previous</button>";

  $markup .= "</div>";

  $markup .= "</div>";
  $markup .= "</div>";

  $markup .= "</div>";
  $markup .= "</section>";

  return $markup;
};

function sonax_blocks_slider_item_render_callback ($block_attributes) {
  global $woocommerce;
  $shop_enabled = get_option('sonax_shop_enabled');

  $post = get_post($block_attributes['product']['id']);
  $product = wc_get_product($block_attributes['product']['id']);

  if (!$product) {
    return '';
  }

  $the_product = $product;

  /*
        If the product is variable try to retrieve a default variation to show
        the default variation in the listing instead of the parent product
        */
  if( $product->is_type('variable') ){
    $default_attributes = $product->get_default_attributes();
    foreach($product->get_available_variations() as $variation_values ){
      foreach($variation_values['attributes'] as $key => $attribute_value ){
        $attribute_name = str_replace( 'attribute_', '', $key );
        $default_value = $product->get_variation_default_attribute($attribute_name);
        if( $default_value == $attribute_value ){
          $is_default_variation = true;
        } else {
          $is_default_variation = false;
          break; // Stop this loop to start next main lopp
        }
      }
      if( $is_default_variation ){
        $variation_id = $variation_values['variation_id'];
        break; // Stop the main loop
      }
    }

    // Now we get the default variation data
    if( $is_default_variation ){
      // Get the "default" WC_Product_Variation object to use available methods
      $the_product = wc_get_product($variation_id);
    }
  }

  $new_products_category_id = get_option('sonax_new_products_category_id');
  $product_categories = get_the_terms( $post->ID, 'product_cat' );

  $product_is_in_category_new = false;

  if ($product_categories) {
    foreach ($product_categories as $key => $value) {
      if ($value->term_id == $new_products_category_id) {
        $product_is_in_category_new = true;
        break;
      }
    }
  }


  $img_brp_0 = wp_get_attachment_image_src($the_product->get_image_id(), '293x195');
  $img_brp_0_2x = wp_get_attachment_image_src($the_product->get_image_id(), '600x400');

  $img_brp_1 = wp_get_attachment_image_src($the_product->get_image_id(), '293x195');
  $img_brp_1_2x = wp_get_attachment_image_src($the_product->get_image_id(), '600x400');

  $img_brp_2 = wp_get_attachment_image_src($the_product->get_image_id(), '375x250');
  $img_brp_2_2x = wp_get_attachment_image_src($the_product->get_image_id(), '750x500');

  $img_brp_3 = wp_get_attachment_image_src($the_product->get_image_id(), '293x195');
  $img_brp_3_2x = wp_get_attachment_image_src($the_product->get_image_id(), '600x400');

  $img_brp_4 = wp_get_attachment_image_src($the_product->get_image_id(), '293x195');
  $img_brp_4_2x = wp_get_attachment_image_src($the_product->get_image_id(), '600x400');

  $img_full = wp_get_attachment_image_src($the_product->get_image_id(), 'full');

  $title =  $the_product->get_name();
  $href = get_permalink( $the_product->get_id() );

  $sale_price = false;
  $regular_price = sonax_custom_format_price($the_product->get_regular_price());
  if( $the_product->is_on_sale() ) {
    $sale_price = sonax_custom_format_price($the_product->get_sale_price());
  } 
  $currency_symbol = get_woocommerce_currency_symbol();

  $markup = "<div class='snx-slider__slide'>";
  $markup .= "<a class='snx-product-box snx-is--color-profiline' href='$href'>";
  $markup .= "<div class='snx-product-box__wrapper'>";

  if ($product_is_in_category_new) {
    $markup .= "<div class='snx-badge snx-badge--round snx-product-box__new'>";
    $markup .= __('NEW', 'sonax');
    $markup .= "</div>";
  }

  if ($sale_price && $shop_enabled) {
    $markup .= "<div class='snx-badge snx-badge--round snx-product-box__discount'>";
    $markup .= __('%', 'sonax');
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-product-box__image'>";
  $markup .= "<picture>";

  if (isset($img_brp_0) && isset($img_brp_0_2x)) {
    $markup .= "<source media='(max-width: 479px)' srcset='". $img_brp_0[0]. ", " . $img_brp_0_2x[0] . " 2x' />";
  } else if (isset($img_brp_0)) {
    $markup .= "<source media='(max-width: 479px)' srcset='". $img_brp_0[0] ."' />";
  }

  if (isset($img_brp_1) && isset($img_brp_1_2x)) {
    $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='". $img_brp_1[0]. ", " . $img_brp_1_2x[0] . " 2x' />";
  } else if (isset($img_brp_1)) {
    $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='". $img_brp_1[0] . "' />";
  }

  if (isset($img_brp_2) && isset($img_brp_2_2x)) {
    $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='". $img_brp_2[0]. ", " . $img_brp_2_2x[0] . " 2x' />";
  } else if (isset($img_brp_2)) {
    $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='". $img_brp_2[0] . "' />";
  }

  if (isset($img_brp_3) && isset($img_brp_3_2x)) {
    $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='". $img_brp_3[0]. ", " . $img_brp_3_2x[0] . " 2x' />";
  } else if (isset($img_brp_3)) {
    $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='". $img_brp_3[0] . "' />";
  }

  if (isset($img_brp_4) && isset($img_brp_4_2x)) {
    $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='". $img_brp_4[0]. ", " . $img_brp_4_2x[0] . " 2x' />";
    $markup .= "<source media='(min-width: 1400px)' srcset='". $img_full[0] . ", " . $img_full[0] . " 2x' />";
  } else if (isset($img_brp_4)) {
    $markup .= "<source media='(min-width: 1200px) and (max-width: 1399px)' srcset='". $img_brp_4[0]. "' />";
    $markup .= "<source media='(min-width: 1400px)' srcset='" . $img_full[0] . "' />";
  }

  $markup .= "<img src='" . $img_full[0] . "'/>";
  $markup .= "</picture>";
  $markup .= "</div>";

  $markup .= "<div class='snx-product-box__detail'>";
  $markup .= "<div class='snx-product-box__title'>$title</div>";

  if ($shop_enabled) {
    if ($sale_price) {
      $markup .= "
      <div class='snx-product-box__price-wrapper'>
      <div class='snx-price snx-price--small snx-price--discount snx-price--text-shadow'>
      <span class='snx-price__value'>$regular_price</span><!--
      --><sup class='snx-price__currency'>$currency_symbol</sup>
      <div class='snx-price__discount-wrapper'>
      <span class='snx-price__discount-value'>$sale_price</span><!--
      --><sup class='snx-price__discount-currency'>$currency_symbol</sup>
      </div>
      </div>
      </div>
      ";
    } else {
      $markup .= "
      <div class='snx-product-box__price-wrapper'>
      <div class='snx-price snx-price--small snx-price--text-shadow'>
      <span class='snx-price__value'>$regular_price</span><!--
      --><sup class='snx-price__currency'>$currency_symbol</sup>
      </div>
      </div>
      ";
    }
  }


  $markup .= "</div>";

  $markup .= "</div>";
  $markup .= "</a>";
  $markup .= "</div>";

  return $markup;
}

function sonax_blocks_image_render_callback($block_attributes) {
  $image_src = $block_attributes['imageUrl'];
  $width = $block_attributes['imageWidth'];
  $align = $block_attributes['imageAlignment'];

  $image_classnames = "";

  $image_classnames .= "snx-align-$align";
  $image_classnames .= " snx-image-$width";

  return "<img src='$image_src' class='$image_classnames' />";
};

function sonax_blocks_video_render_callback($block_attributes) {
  $title = $block_attributes['title'];
  $type = $block_attributes['videoType'];
  $src = $block_attributes['videoUrl'];
  $poster = false;

  $markup = "<section class='snx-page-section'>";

  if (isset($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";	
  $markup .= "<div class='snx-video'>";

  if (!empty($block_attributes['videoPoster'])) {
    $poster = $block_attributes['videoPoster'];
  }

  if ($type === 'youtube') {
    $markup .= "<iframe src='https://www.youtube.com/embed/$src' frameborder='0' allow='accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share' allowfullscreen></iframe>";
  } else {
    $markup .= "<video src='$src' controls></video>";
  }

  $markup .= "</div>";

  $markup .= "</div>";
  $markup .= "</section>";

  return $markup;
};

function sonax_blocks_section_render_callback($block_attributes, $content) {

  if (isset($block_attributes['title'])) {
    $title = $block_attributes['title'];
  }

  $markup = "<section class='snx-page-section'>";
  if (!empty($title)) {
    $markup .= "<div class='snx-page-section__header'>";
    $markup .= "<h2 class='snx-page-section__headline'>$title</h2>";
    $markup .= "</div>";
  }

  $markup .= "<div class='snx-page-section__body'>";
  $markup .= "<div class='snx-rich-text snx-rich-text--is-block'>$content</div>";
  $markup .= "</div>";

  $markup .= "</section>";

  return $markup;

}

/**
 *
 * Enqueue Gutenberg block assets for both frontend + backend.
 *
 * Assets enqueued:
 * 1. blocks.style.build.css - Frontend + Backend.
 * 2. blocks.build.js - Backend.
 * 3. blocks.editor.build.css - Backend.
 *
 * @uses {wp-blocks} for block type registration & related functions.
 * @uses {wp-element} for WP Element abstraction — structure of blocks.
 * @uses {wp-i18n} to internationalize the block's text.
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function sonax_blocks_cgb_block_assets() { // phpcs:ignore

	$sonax_gmaps_api_key = get_option('sonax_gmaps_api_key');

	if (is_admin()) {
		// Register block editor script for backend.
		wp_enqueue_script(
			'sonax_blocks-cgb-block-js', // Handle.
			get_template_directory_uri() . '/dist/blocks.bundle.js', // Block.build.js: We enqueue the block here. Built with Webpack.
			array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor', 'wp-api-fetch', 'wp-components' ), // Dependencies, defined above.
			null, // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: filemtime — Gets file modification time.
			false // Enqueue the script in the footer.
		);

		wp_add_inline_script( 'sonax_blocks-cgb-block-js', "window.sonax_gmaps_api_key = '$sonax_gmaps_api_key';" );
	
		wp_enqueue_style(
			'sonax_blocks-cgb-block-editor-css', // Handle.
			get_template_directory_uri() . '/blocks.css', // Block editor CSS.
			array( 'wp-edit-blocks' ), // Dependency to include the CSS after it.
			null // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
		);
	}


	/**
	 * Register Gutenberg block on server-side.
	 *
	 * Register the block on server-side to ensure that the block
	 * scripts and styles for both frontend and backend are
	 * enqueued when the editor loads.
	 *
	 * @link https://wordpress.org/gutenberg/handbook/blocks/writing-your-first-block-type#enqueuing-block-scripts
	 * @since 1.16.0
	 */


	register_block_type(
		'snx/block-section', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_section_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string'
				]
			]
		)
	);


	register_block_type(
		'snx/block-video', array(
			// Enqueue blocks.style.build.css on both frontend & backend.
			// 'style'         => 'sonax_blocks-cgb-style-css',
			// Enqueue blocks.build.js in the editor only.
			'editor_script' => 'sonax_blocks-cgb-block-js',
			// Enqueue blocks.editor.build.css in the editor only.
			// 'editor_style'  => 'sonax_blocks-cgb-block-editor-css',
			'render_callback' => 'sonax_blocks_video_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string'
				],
				'videoUrl' => [
					'type' => 'string'
				],
				'videoPoster' => [
					'type' => 'string'
				],
				'videoType' => [
					'type' => 'string',
					'default' => 'mp4'
				]
			]
		)
	);


	register_block_type(
		'snx/block-image', array(
			// Enqueue blocks.style.build.css on both frontend & backend.
			// 'style'         => 'sonax_blocks-cgb-style-css',
			// Enqueue blocks.build.js in the editor only.
			'editor_script' => 'sonax_blocks-cgb-block-js',
			// Enqueue blocks.editor.build.css in the editor only.
			// 'editor_style'  => 'sonax_blocks-cgb-block-editor-css',
			'render_callback' => 'sonax_blocks_image_render_callback',
			'attributes' => [
				'imageUrl' => [
					'type' => 'string'
				],
				'imageAlignment' => [
					'type' => 'string',
					'default' => 'center'
				],
				'imageWidth' => [
					'type' => 'string',
					'default' => '100',
				]
			]
		)
	);


	register_block_type(
		'snx/block-slider-item', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_slider_item_render_callback',
			'attributes' => [
				'product' => [
					'type' => 'object',
				]
			]
		)
	);


	register_block_type(
		'snx/block-product-slider', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_product_slider_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string'
				],
			]
		)
	);


	register_block_type(
		'snx/block-image-gallery', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_image_gallery_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string'
				],
				'innerBlocks' => [
					'type' => 'array',
					'items' => [
						'type' => 'object'
					]
				]
			]
		)
	);


	register_block_type(
		'snx/block-image-gallery-item', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_image_gallery_item_render_callback',
			'attributes' => [
				'imageUrl' => [
					'type' => 'object'
				],
				'id' => [
					'type' => 'number'
				]
			]
		)
	);



	register_block_type(
		'snx/block-stage', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_stage_render_callback',
			'attributes' => [
				'invert' => [
					'type' => 'boolean',
					'default' => false
				],
				'stageImageUrl' => [
					'type' => 'object'
				],
				'showFeaturedImage' => [
					'type' => 'boolean',
					'default' => false
				],
				'featuredImageUrl' => [
					'type' => 'object'
				],
				'headline' => [
					'type' => 'string'	
				],
				'showCta' => [
					'type' => 'boolean',
					'default' => false
				],
				'ctaLabel' => [
					'type' => 'string',
					'default' => ''
				],
				'postLink' => [
					'type' => 'string',
					'default' => ''
                ],
			]
		)
	);


	register_block_type(
		'snx/block-teaser', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_teaser_render_callback',
			'attributes' => [
				'headline' => [
					'type' => 'string',
				],
				'text' => [
					'type' => 'string',
				],
				'postLink' => [
					'type' => 'string',
					'default' => ''
				],
				'postLinkExternal' => [
					'type' => 'boolean',
					'default' => false
				],
				'postLinkNewTab' => [
					'type' => 'boolean',
					'default' => false
				],
				'imageUrl' => [
					'type' => 'object',
				],
				'ctaLabel' => [
					'type' => 'string',
					'default' => ''
				],
				'invert' => [
					'type' => 'boolean',
					'default' => false
                ],
				'cover' => [
					'type' => 'boolean',
					'default' => false
                ],
                'showFeaturedImage' => [
					'type' => 'boolean',
					'default' => false
				],
				'featuredImageUrl' => [
					'type' => 'object',
                    'default' => false
                ]
			]
		)
	);


	register_block_type(
		'snx/block-teaser-row', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_teaser_row_render_callback',
			'attributes' => [
				'layout' => [
					'type' => 'string'
				],
				'title' => [
					'type' => 'string'
				]
			]
		)
	);

    /* Block Informal Teaser */


	register_block_type(
		'snx/block-informal-teaser', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_informal_teaser_render_callback',
			'attributes' => [
				'headline' => [
					'type' => 'string',
				],
				'text' => [
					'type' => 'string',
				],
				'postLink' => [
					'type' => 'string',
					'default' => ''
				],
				'postLinkExternal' => [
					'type' => 'boolean',
					'default' => false
				],
				'postLinkNewTab' => [
					'type' => 'boolean',
					'default' => false
				],
				'imageUrl' => [
					'type' => 'object',
				],
				'ctaLabel' => [
					'type' => 'string',
					'default' => ''
				]
			]
		)
	);


	register_block_type(
		'snx/block-informal-teaser-row', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_informal_teaser_row_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string'
				]
			]
		)
	);

	/* Block Accordion */


	register_block_type(
		'snx/block-accordion-item', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_accordion_item_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string',
					'default' => ''
				],
				'subtitle' => [
					'type' => 'string',
					'default' => ''
				],
			]
		)
	);


	register_block_type(
		'snx/block-accordion', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_accordion_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string',
					'default' => ''
				]
			]
		)
	);


	register_block_type(
		'snx/block-card', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_card_render_callback',
			'attributes' => [
				'headline' => [
					'type' => 'string',
					'default' => ''
				],
				'text' => [
					'type' => 'string',
					'default' => ''
				],
				'postLink' => [
					'type' => 'string',
					'default' => ''
				],
				'imageUrl' => [
					'type' => 'object',
				],
			]
		)
	);


	register_block_type(
		'snx/block-card-row', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_card_row_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string',
					'default' => ''
				]
			]
		)
	);

	/* Block Person List */


	register_block_type(
		'snx/block-person-list', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_person_list_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string'
				],
				'personCount' => [
					'type' => 'number'
				]
			]
		)
	);


	register_block_type(
		'snx/block-person-list-item', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_person_list_item_render_callback',
			'attributes' => [
				'person' => [
					'type' => 'object'
				]
			]
		)
	);

	/* Block Quote */


	register_block_type(
		'snx/block-quote', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_quotes_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string'
				],
				'citation' => [
					'type' => 'string'
				],
				'imageUrl' => [
					'type' => 'object'
				]
			]
		)
	);

	/* Locations Block */


	register_block_type(
		'snx/block-locations', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_locations_render_callback',
			'attributes' => [
				'lat' => [
					'type' => 'number'
				],
				'lng' => [
					'type' => 'number'
				],
				'title' => [
					'type' => 'string'
				]
			]
		)
	);

	/* Block Insertion */


	register_block_type(
		'snx/block-insertion', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_insertions_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string'
				]
			]
		)
	);
		
	/* Block Application Guide */


	register_block_type(
		'snx/block-application-guide-item', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_application_guide_item_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string',
				],
				'image' => [
					'type' => 'object',
				]
			]
		)
	);	


	
	register_block_type(
		'snx/block-application-guide', array(
			'editor_script' => 'sonax_blocks-cgb-block-js',
			'render_callback' => 'sonax_blocks_application_guide_render_callback',
			'attributes' => [
				'title' => [
					'type' => 'string',
				],
				'layout' => [
					'type' => 'string',
				]
			]
		)
	);	

}

// Hook: Block assets.
add_action( 'enqueue_block_assets', 'sonax_blocks_cgb_block_assets' );

function sonax_block_category( $categories, $post ) {
	return array_merge(
		$categories,
		array(
			array(
				'slug' => 'sonax-blocks',
				'title' => __( 'Sonax Blocks', 'sonax-blocks' ),
			),
		)
	);
}
add_filter( 'block_categories_all', 'sonax_block_category', 10, 2);

add_filter( 'allowed_block_types_all', 'sonax_allowed_block_types' );
 
function sonax_allowed_block_types( $allowed_blocks ) {
 
	return array(
		'core/paragraph',
		'core/shortcode',
		'core/heading',
		'core/list',
		'snx/block-stage',
		'snx/block-section',
		'snx/block-image',
		'snx/block-image-gallery',
		'snx/block-image-gallery-item',
		'snx/block-video',
		'snx/block-product-slider',
		'snx/block-slider-item',
		'snx/block-informal-teaser-row',
		'snx/block-informal-teaser',
		'snx/block-teaser-row',
		'snx/block-teaser',
		'snx/block-card-row',
		'snx/block-card',
		'snx/block-accordion',
		'snx/block-accordion-item',
		'snx/block-person-list-item',
		'snx/block-person-list',
		'snx/block-insertion',
		'snx/block-application-guide',
		'snx/block-application-guide-item',
		'snx/block-quote',
		'snx/block-locations'
	);
 
}

add_theme_support( 'disable-custom-colors' );
add_theme_support( 'disable-custom-font-sizes' );
add_theme_support( 'disable-custom-gradients' );
add_theme_support( 'editor-styles' );

function snx_do_shortcode_in_block_content($block_content, $block) {
    // This is to support shortcodes coming from the core/shortcode block.
    // On woocommerce pages, the content of checkout etc. is also a shortcode.
    // If this function is active on "native" woocomerce pages, the whole content of the
    // page is wrapped inside a <p></p> and breaks all markup.
    if (!is_realy_woocommerce_page()) {
        return do_shortcode($block_content, true);
    } else {
        return $block_content;
    }
}

add_filter( 'render_block', 'snx_do_shortcode_in_block_content', 99, 2 );
