<?php
/**
 * Adds and configures a custom post type location and exposes all of its fields to the wordpress rest api
 *
 */

function sonax_add_locations_category () {
  wp_create_category('Reseller');
}

add_action( 'admin_init', 'sonax_add_locations_category' );

function sonax_register_locations_cpt() {
	$labels = [
		"name" => __( "Locations", "sonax" ),
		"singular_name" => __( "Location", "sonax" ),
	];

	$args = [
		"label" => __( "Locations", "sonax" ),
		"labels" => $labels,
		"description" => "",
		"public" => true,
		"publicly_queryable" => false,
		"show_ui" => true,
		"show_in_rest" => true,
		"rest_base" => "",
		"rest_controller_class" => "WP_REST_Posts_Controller",
		"has_archive" => false,
		"show_in_menu" => true,
		"show_in_nav_menus" => false,
		"delete_with_user" => false,
		"exclude_from_search" => true,
		"capability_type" => "post",
		"map_meta_cap" => true,
		"hierarchical" => false,
		"rewrite" => [ "slug" => "location", "with_front" => true ],
		"query_var" => true,
		"supports" => [ "title" ],
		"taxonomies" => [ "category" ],
	];

	register_post_type( "location", $args );
}

add_action( 'init', 'sonax_register_locations_cpt' );

add_action( 'admin_print_scripts-post-new.php', 'locations_admin_script', 11 );
add_action( 'admin_print_scripts-post.php', 'locations_admin_script', 11 );

function locations_admin_script() {
    global $post_type;
    global $pagenow;
    if( 'location' == $post_type && $pagenow === 'post-new.php' ) {
      wp_enqueue_script( 'locations-admin-script', get_template_directory_uri() . '/inc/js/locations.js' );
    }
}

function sonax_acf_google_map_api( $api ){
	
	$gmaps_api_key = get_option('sonax_gmaps_api_key');

	$api['key'] = $gmaps_api_key;
	
	return $api;
	
}

add_filter('acf/fields/google_map/api', 'sonax_acf_google_map_api');