<?php
/**
 * Creates a custom options page for the product import and enqueues its scripts (react app). 
 * A custom rest api endpoint is created to store woocommerce api tokens from a callback url in wp-options.
 * Api tokens and acf json files are inlined into the apps markup / script so the JS can access them without calling additional rest apis.
 *
 */

function get_acf_field_jsons () {
  $dir = new DirectoryIterator( get_template_directory()  . '/acf-json' );

  $result = array();

  foreach( $dir as $file ) {

    if ($file->getFilename() == '.') {
      continue;
    }
    
    if ($file->getFilename() == '..') {
      continue;
    }

    $json = json_decode( file_get_contents( $file->getPathname() ), true );


    $result[$file->getFilename()] = $json;

  }

  return $result;
}

function sonax_product_import_page () {

  $consumer_key = get_option('sonax-product-import-consumer-key');
  $consumer_secret = get_option('sonax-product-import-consumer-secret');
  $acf_json = json_encode(get_acf_field_jsons());

  ?>
    <script>
      window.acfJson = JSON.parse('<?php echo $acf_json; ?>');
      window.wcConsumerKey = "<?php echo $consumer_key; ?>";
      window.wcConsumerSecret = "<?php echo $consumer_secret; ?>";
    </script>
    <div id="sonax-product-import" class="wrap"></div>
  <?php
}

function sonax_add_product_import_page () {
  $product_import_page = add_submenu_page("sonax-theme-options", "Product Import Generator", "Product Import Generator", "manage_options", "sonax-product-import", "sonax_product_import_page", null, 40);

  // Load the JS conditionally
  add_action( 'load-' . $product_import_page, 'sonax_load_product_import_js' );
}

// This function is only called when our plugin's page loads!
function sonax_load_product_import_js(){
    // Unfortunately we can't just enqueue our scripts here - it's too early. So register against the proper action hook to do it
    add_action( 'admin_enqueue_scripts', 'sonax_enqueue_product_import_js' );
}

function sonax_enqueue_product_import_js(){
    // Isn't it nice to use dependencies and the already registered core js files?
    $theme = wp_get_theme();
    $version = $theme->get('Version');
    wp_enqueue_script( 'sonax-product-import', get_template_directory_uri() . '/dist/product-import.bundle.js', array( 'wp-api', 'wp-i18n', 'wp-components', 'wp-element' ), $version, true );

    wp_enqueue_style(
		'sonax_blocks-cgb-block-editor-css', // Handle.
      get_template_directory_uri() . '/blocks.css', // Block editor CSS.
      array( 'wp-edit-blocks' ), // Dependency to include the CSS after it.
      null // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
    );
}

add_action("admin_menu", "sonax_add_product_import_page");



add_action( 'rest_api_init', function () {
    register_rest_route('wp/v2', 'sonax-woocommerce-product-import', array(
        'methods' => array('GET', 'POST'),
        'callback' => 'sonax_woocommerce_product_import_callback',
        'permission_callback' => function () {
          return true;
        }
    ));
} );

function sonax_woocommerce_product_import_callback () {
  // {
  //   "key_id": 1,
  //   "user_id": 123,
  //   "consumer_key": "ck_xxxxxxxxxxxxxxxx",
  //   "consumer_secret": "cs_xxxxxxxxxxxxxxxx",
  //   "key_permissions": "read_write"
  // }

  $inputJSON = file_get_contents('php://input');
  $input = json_decode($inputJSON, TRUE); //convert JSON into array

  update_option('sonax-product-import-consumer-key', $input['consumer_key']);
  update_option('sonax-product-import-consumer-secret', $input['consumer_secret']);

  echo $inputJSON;
};

// add_filter( 'woocommerce_rest_check_permissions', 'dcwd_allow_rest_api_queries', 10, 4 ); 
// function dcwd_allow_rest_api_queries( $permission, $context, $zero, $object ) {
// 	// Optionally limit permitted queries to different contexts.
// 	/*if ( 'read' != $context ) {
// 		return $permission;
// 	}*/
// 	// Write the parameters to the error log (or debug.log file) to see what requests are being accessed.
// 	//error_log( sprintf( 'Permission: %s, Context: %s; Object: %s', var_export( $permission, true ), $context, var_export( $object, true ) ) );

// 	return true;  // Allow all queries.
// }

// add_action('http_api_curl', function( $handle ){
//   //Don't verify SSL certs
//   curl_setopt($handle, CURLOPT_SSL_VERIFYPEER, false);
//   curl_setopt($handle, CURLOPT_SSL_VERIFYHOST, false);

// }, 10);