<?php

function is_realy_woocommerce_page () {
    if( function_exists ( "is_woocommerce" ) && is_woocommerce()){
        return true;
    }
    $woocommerce_keys = array ( "woocommerce_shop_page_id" ,
        "woocommerce_terms_page_id" ,
        "woocommerce_cart_page_id" ,
        "woocommerce_checkout_page_id" ,
        "woocommerce_pay_page_id" ,
        "woocommerce_thanks_page_id" ,
        "woocommerce_myaccount_page_id" ,
        "woocommerce_edit_address_page_id" ,
        "woocommerce_view_order_page_id" ,
        "woocommerce_change_password_page_id" ,
        "woocommerce_logout_page_id" ,
        "woocommerce_lost_password_page_id" ) ;

    foreach ( $woocommerce_keys as $wc_page_id ) {
        if ( get_the_ID () == get_option ( $wc_page_id , 0 ) ) {
            return true ;
        }
    }
    return false;
}

function snx_filter_woocommerce_form_field( $field, $key, $args, $value, $custom_attributes = [] ) {
    switch ($args['type']) {
        /* All <input> types  */
        case 'text':
        case 'password':
        case 'datetime':
        case 'datetime-local':
        case 'date':
        case 'month':
        case 'time':
        case 'week':
        case 'number':
        case 'email':
        case 'url':
        case 'tel':
            $field_override = '<div class="snx-form-group">';
            $field_override .= '<label class="snx-form-group__label">' . $args['label'] . '</label>';            
            $field_override .= '<input type="' . esc_attr( $args['type'] ) . '" class="snx-form-text" name="' . esc_attr($key) . '" placeholder="' . $args['placeholder'] . '" id="' . esc_attr( $args['id'] ) . '" value="' . esc_attr($value). '" />';
            $field_override .= "</div>";

            return $field_override;

        /* <textarea> */
        case 'textarea':
            $field_override = '<div class="snx-form-group">';
            $field_override .= '<label class="snx-form-group__label">' . $args['label'] . '</label>';
            $field_override .= '<textarea name="' . esc_attr( $key ) . '" class="snx-form-textarea" id="' . esc_attr( $args['id'] ) . '" placeholder="' . esc_attr( $args['placeholder'] ) . '" ' . ( empty( $args['custom_attributes']['rows'] ) ? ' rows="2"' : '' ) . ( empty( $args['custom_attributes']['cols'] ) ? ' cols="5"' : '' ) . implode( ' ', $custom_attributes ) . '>' . esc_textarea( $value ) . '</textarea>';
            $field_override .= "</div>";

            return $field_override;

        /* <checkbox> */
        case 'checkbox':
                $field_override = '<div class="snx-form-group">';
				$field_override .= '<label class="snx-form-checkbox__container">';
				$field_override .= '<input type="' . esc_attr( $args['type'] ) . '" class="snx-form-checkbox__input" name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" value="1" ' . checked( $value, 1, false ) . ' /> ' . $args['label'] . $required . '</label>';
                $field_override .= '<span class="snx-form-checkbox__checkmark"></span>';
                $field_override .= '<span class="snx-form-checkbox__label">';
                $field_override .= $args['label'];
                $field_override .= '</span>';
                $field_override .= '</label>';
                $field_override .= "</div>";

            return $field_override;

        /* <select> */
        case 'select':
				$field_override = '<div class="snx-form-group">';
                $field_override .= '<label class="snx-form-group__label">' . $args['label'] . '</label>';
				$options = '';

				if ( ! empty( $args['options'] ) ) {
					foreach ( $args['options'] as $option_key => $option_text ) {
						if ( '' === $option_key ) {
							// If we have a blank option, select2 needs a placeholder.
							if ( empty( $args['placeholder'] ) ) {
								$args['placeholder'] = $option_text ? $option_text : __( 'Choose an option', 'woocommerce' );
							}
							$custom_attributes[] = 'data-allow_clear="true"';
						}
						$options .= '<option value="' . esc_attr( $option_key ) . '" ' . selected( $value, $option_key, false ) . '>' . esc_html( $option_text ) . '</option>';
					}

				}
                $field_override .= '<select name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" class="snx-form-select" ' . implode( ' ', $custom_attributes ) . ' data-placeholder="' . esc_attr( $args['placeholder'] ) . '">' . $options . '</select>';
                
                $field_override .= "</div>";
				return $field_override;
        /* Country */
        case 'country':
                $countries = 'shipping_country' === $key ? WC()->countries->get_shipping_countries() : WC()->countries->get_allowed_countries();

				$field_override = '<div class="snx-form-group">';
                $field_override .= '<label class="snx-form-group__label">' . $args['label'] . '</label>';
                $options = '';

                foreach ( $countries as $ckey => $cvalue ) {
                    $options .= '<option value="' . esc_attr( $ckey ) . '" ' . selected( $value, $ckey, false ) . '>' . esc_html( $cvalue ) . '</option>';
                }

                $field_override .= '<select name="' . esc_attr( $key ) . '" id="' . esc_attr( $args['id'] ) . '" class="snx-form-select" ' . implode( ' ', $custom_attributes ) . ' data-placeholder="' . esc_attr( $args['placeholder'] ) . '">' . $options . '</select>';
                $field_override .= "</div>";

				return $field_override;
        /* State (skipped for now until someone wants it. State information seems to be redundant information when a ZIP code is already provided) */
        case 'state':
            return '';
        default:
            return $field;
    }

    return $field;
}
add_filter( 'woocommerce_form_field', 'snx_filter_woocommerce_form_field', 10, 4 );

function snx_remove_div_class_woocommerce($content) {
  libxml_use_internal_errors(true);
	
  if (!empty($content)) {
	  $html = new DOMDocument();
	  $html->loadHTML(mb_convert_encoding($content, 'HTML-ENTITIES', 'UTF-8'), LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);

	  $container = (new DOMXpath($html))->query("//div[contains(@class,'woocommerce')]")[0];
	  if ($container) {
		foreach ($container->childNodes as $child) {
		  $container->parentNode->insertBefore($child->cloneNode(true), $container);
		}
		$container->parentNode->removeChild($container);
	  }
	  return $html->saveHTML();
  }
}
add_filter('the_content', 'snx_remove_div_class_woocommerce', 100);

function snx_woocommerce_payment_gateway_get_saved_payment_method_option_html($html, $token, $instance) {
    $html = sprintf(
			'<li class="woocommerce-SavedPaymentMethods-token">
                <div class="snx-form-radio">
				    <input id="wc-%1$s-payment-token-%2$s" type="radio" name="wc-%1$s-payment-token" value="%2$s" style="width:auto;" class="woocommerce-SavedPaymentMethods-tokenInput snx-form-radio__input" %4$s />
				    <label class="snx-form-radio__container" for="wc-%1$s-payment-token-%2$s">
                        <span class="snx-form-radio__checkmark"></span>
                        <span class="snx-form-radio__label">
                            %3$s
                        </span>
                    </label>
                </div>
			</li>',
			esc_attr( $instance->id ),
			esc_attr( $token->get_id() ),
			esc_html( $token->get_display_name() ),
			checked( $token->is_default(), true, false )
		);

    return $html;
}

add_filter( 'woocommerce_payment_gateway_get_saved_payment_method_option_html', 'snx_woocommerce_payment_gateway_get_saved_payment_method_option_html', 10, 3 );

function snx_wc_payment_gateway_form_saved_payment_methods_html($html, $instance) {

    $html = '<ul class="woocommerce-SavedPaymentMethods wc-saved-payment-methods" data-count="' . esc_attr( count( $instance->get_tokens() ) ) . '" style="list-style-type: none; margin: 0px; padding: 0px;">';

    foreach ( $instance->get_tokens() as $token ) {
        $html .= $instance->get_saved_payment_method_option_html( $token );
    }

    $html .= $instance->get_new_payment_method_option_html();
    $html .= '</ul>';

    return $html;
}

add_filter( 'wc_payment_gateway_form_saved_payment_methods_html', 'snx_wc_payment_gateway_form_saved_payment_methods_html', 10, 3 );

function snx_woocommerce_payment_gateway_get_new_payment_method_option_html($html, $instance) {
    $label = apply_filters( 'woocommerce_payment_gateway_get_new_payment_method_option_html_label', $instance->new_method_label ? $instance->new_method_label : __( 'Use a new payment method', 'woocommerce' ), $instance );
    $html  = sprintf(
        '<li class="woocommerce-SavedPaymentMethods-new">
            <div class="snx-form-radio">
                <input id="wc-%1$s-payment-token-new" type="radio" name="wc-%1$s-payment-token" value="new" style="width:auto;" class="woocommerce-SavedPaymentMethods-tokenInput snx-form-radio__input" />
                <label class="snx-form-radio__container" for="wc-%1$s-payment-token-new">
                    <span class="snx-form-radio__checkmark"></span>
                    <span class="snx-form-radio__label">
                        %2$s
                    </span>
                </label>
            </div>
        </li>',
        esc_attr( $instance->id ),
        esc_html( $label )
    );

    return $html;
}

add_filter( 'woocommerce_payment_gateway_get_new_payment_method_option_html', 'snx_woocommerce_payment_gateway_get_new_payment_method_option_html', 10, 3 );

/* WC seems to use its internal function here, which does not allow for filtering. Only relevant if users are logged in. Anonymous users cannot save their payment methods. GG  */

function snx_woocommerce_payment_gateway_save_new_payment_method_option_html($html, $instance) {
    $html = sprintf(
        '<p class="form-row woocommerce-SavedPaymentMethods-saveNew">
            <div class="snx-form-checkbox">
                <label for="wc-%1$s-new-payment-method" class="snx-form-checkbox__container">
                    <input id="wc-%1$s-new-payment-method" name="wc-%1$s-new-payment-method" type="checkbox" value="true" style="width:auto;" class="snx-form-checkbox__input" />
                    <span class="snx-form-checkbox__checkmark"></span>
                    %2$s
                </label>
            </div>
        </p>',
        esc_attr( $instance->id ),
        esc_html__( 'Save to account', 'woocommerce' )
    );

    return $html;
}

add_filter( 'woocommerce_payment_gateway_save_new_payment_method_option_html', 'snx_woocommerce_payment_gateway_save_new_payment_method_option_html', 10, 3);

function clean($str)
{       
    $str = utf8_decode($str);
    $str = str_replace("&nbsp;", "", $str);
    $str = preg_replace('/\s+/', ' ',$str);
    $str = trim($str);
    return $str;
}


function sonax_custom_format_price($price) {
    $result = clean(str_replace(get_woocommerce_currency_symbol(), '', strip_tags(wc_price($price))));
    return $result;
}