<?php
/**
 * This file holds all general theme settings and configurations
 *
 */

/* Theme assets */


function sonax_assets()
{   
    wp_enqueue_style( 'sonax-default-styles', get_stylesheet_uri());
    wp_style_add_data( 'sonax-default-styles', 'rtl', 'replace' );
    wp_enqueue_script( 'sonax-scripts', get_theme_file_uri( '/dist/style.bundle.js' ), array(), NULL, false );
    wp_enqueue_script( 'sonax-scripts' );
}

add_action( 'wp_enqueue_scripts', 'sonax_assets' );

/* Render page titles from slug */

function sonax_slug_setup() {
    add_theme_support( 'title-tag' );
}
add_action( 'after_setup_theme', 'sonax_slug_setup' );

/* Configure body class depending on pages content */

function sonax_body_class( $classes ) {

  global $post;
  global $template;

  if (isset($post->post_content) && has_blocks($post->post_content)) {
    $blocks = parse_blocks($post->post_content);
    if ($blocks[0]['blockName'] === "snx/block-stage") {
      $classes[] = 'snx-template-a';
    } else {
      $classes[] = 'snx-template-b';
    }
  } else {
    if ( basename( $template ) === 'single-product.php') {
      $classes[] = 'snx-template-a';
    } elseif ( basename( $template ) == 'taxonomy-product-cat.php' ) {

      $is_category_page = is_product_category();
      $term = get_queried_object();
      $show_stage = get_field('show_stage', $term);

      if ($is_category_page && $show_stage) {
        $classes[] = 'snx-template-a';
      } else {
        $classes[] = 'snx-template-b';
      }

    } else {
      $classes[] = 'snx-template-b';
    }
  }


  $classes[] = 'snx-katana';
  
  return $classes;
}

add_filter( 'body_class','sonax_body_class' );

/* Create an example page and set it as frontpage upon theme activation */

if (isset($_GET['activated']) && is_admin()){
  
    $new_page_title = 'Welcome to the Sonax wordpress theme';
    $new_page_content = '<!-- wp:snx/block-section {"title":""} -->
<!-- wp:paragraph -->
<p>Great, you´ve installed our theme for a unified SONAX brand-experience. <br>For the next steps, you can </p>
<!-- /wp:paragraph -->

<!-- wp:list -->
<ul><li>Build editorial Pages</li><li>Add product data and -categories</li><li>Build your Websitesitenavigations</li></ul>
<!-- /wp:list -->

<!-- wp:paragraph -->
<p>For further information, tips and support visit <a href="http://theme.sonax.com" target="_blank" rel="noreferrer noopener">theme.sonax.com</a>.</p>
<!-- /wp:paragraph -->
<!-- /wp:snx/block-section -->';
    $new_page_template = ''; //ex. template-custom.php. Leave blank if you don't want a custom page template.
  
    //don't change the code bellow, unless you know what you're doing
  
    $page_check = get_page_by_title($new_page_title);
    $new_page = array(
        'post_type' => 'page',
        'post_title' => $new_page_title,
        'post_content' => $new_page_content,
        'post_status' => 'publish',
        'post_author' => 1,
    );
    if(!isset($page_check->ID)){
        $new_page_id = wp_insert_post($new_page);
        if(!empty($new_page_template)){
            update_post_meta($new_page_id, '_wp_page_template', $new_page_template);
        }
        update_option( 'page_on_front', $new_page_id );
        update_option( 'show_on_front', 'page' );
    }
  
}