<?php
/**
 * Configure all woocommerce related options and customizations
 *
 */

/* Declare theme as woocommerce compatible */

function sonax_add_woocommerce_support() {
  add_theme_support( 'woocommerce' );
}

add_action( 'after_setup_theme', 'sonax_add_woocommerce_support' );

/* Change number of products that are displayed per page (shop page) */

add_filter( 'loop_shop_per_page', 'new_loop_shop_per_page', 20 );

function new_loop_shop_per_page( $cols ) {
  // $cols contains the current number of products per page based on the value stored on Options –> Reading
  // Return the number of products you wanna show per page.
  $cols = 15;
  return $cols;
}

/* Remove default woocommerce styles from frontend */

add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/* Add custom fields and acf js for products and product variations */ 

$GLOBALS['wc_loop_variation_id'] = null;

function is_field_group_for_variation($field_group, $variation_data, $variation_post) {
	return (preg_match( '/Variation/i', $field_group['title'] ) == true);
}

add_action( 'woocommerce_product_after_variable_attributes', function( $loop_index, $variation_data, $variation_post ) {
	$GLOBALS['wc_loop_variation_id'] = $variation_post->ID;

	foreach ( acf_get_field_groups() as $field_group ) {
		if ( is_field_group_for_variation( $field_group, $variation_data, $variation_post ) ) {
			acf_render_fields( $variation_post->ID, acf_get_fields( $field_group ) );
		}
	}

	$GLOBALS['wc_loop_variation_id'] = null;
}, 10, 3 );

add_action( 'woocommerce_save_product_variation', function( $variation_id, $loop_index ) {
	if ( !isset( $_POST['acf_variation'][$variation_id] ) ) {
		return;
	}

	$_POST['acf'] = $_POST['acf_variation'][$variation_id];

  // acf()->input->save_post( $variation_id );
  do_action( 'acf/save_post', $variation_id );
}, 10, 2 );

add_filter( 'acf/prepare_field', function ( $field ) {
	if ( !$GLOBALS['wc_loop_variation_id'] ) {
		return $field;
	}

	$field['name'] = preg_replace( '/^acf\[/', 'acf_variation[' . $GLOBALS['wc_loop_variation_id'] . '][', $field['name'] );

	return $field;
}, 10, 1);

function sonax_admin_head_post() {
	global $post_type;
	if ($post_type === 'product') {
		wp_register_script( 'sonax-acf-variation', get_template_directory_uri() . '/inc/js/acf-variation.js', array(
			'jquery-core',
			'jquery-ui-core'
		), '1.1.0',
			true ); // Custom scripts
		
		wp_enqueue_script( 'sonax-acf-variation' ); // Enqueue it!

	}
}

/* actions fired when adding/editing posts or pages */
/* admin_head-(hookname) */
add_action( 'admin_head-post.php', 'sonax_admin_head_post' );
add_action( 'admin_head-post-new.php',  'sonax_admin_head_post' );

// add ACF rule
add_filter('acf/location/rule_values/post_type', 'acf_location_rule_values_Post');
function acf_location_rule_values_Post( $choices ) {
	$choices['product_variation'] = 'Product Variation';
    //print_r($choices);
    return $choices;
}

/* Remove shop functionalities as woocommerce is only used as catalog */

add_action( 'admin_bar_menu', 'snx_remove_wp_admin_bar_nodes', 999 );

function snx_remove_wp_admin_bar_nodes() 
{
    global $wp_admin_bar;   
    // $wp_admin_bar->remove_node( 'new-post' );
    $wp_admin_bar->remove_node( 'new-link' );
    $wp_admin_bar->remove_node( 'new-media' );
    $wp_admin_bar->remove_node( 'new-shop_coupon' );
    $wp_admin_bar->remove_node( 'new-shop_order' );
};

/* Create category for new products if not already present upon theme activation / startup */
function snx_create_products_new_category() {
	/* Check if woocommerce is available before running the code */
	if ( class_exists( 'WooCommerce' ) ) {
		$new_products_category_id = get_option('sonax_new_products_category_id');
		$new_products_category_exists = false;

		if (!empty($new_products_category_id)) {
			if (!empty(get_term($new_products_category_id))) {
				$new_products_category_exists = true;
			}
		}

		if (!$new_products_category_exists) {
			$new_category = wp_insert_term( 'Sonax New', 'product_cat', array());

			$new_category_id = $new_category['term_id'];

			update_option('sonax_new_products_category_id', $new_category_id);
		}
	}
}
	

add_action('init', 'snx_create_products_new_category');
