const path = require('path')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
// const BrowserSyncPlugin = require('browser-sync-webpack-plugin')

const OUTPUT_BASE_PATH = __dirname
console.log(OUTPUT_BASE_PATH)

module.exports = {
  entry: {
    style: './src/style/index.js',
    blocks: './src/blocks/index.js',
    'product-import': './src/product-import/index.js',
  },
  output: {
    path: OUTPUT_BASE_PATH,
    filename: 'dist/[name].bundle.js',
    assetModuleFilename: 'dist/assets/[hash][ext][query]',
  },
  module: {
    rules: [
      //babel
      {
        test: /\.js$/,
        exclude: /node_modules/,
        loader: 'babel-loader',
        options: {
          presets: [['@babel/preset-env']],
          plugins: [
            ['lodash'],
            [
              '@babel/transform-react-jsx',
              {
                pragma: 'wp.element.createElement',
              },
            ],
          ],
        },
      },
      //style and css extract
      {
        test: [/.css$/],
        use: [MiniCssExtractPlugin.loader, 'css-loader'],
      },
      //fonts
      {
        test: /\.(ttf|eot|woff(2)?|jpeg|jpg|png|svg)$/,
        type: 'asset/resource',
      },
    ],
  },
  plugins: [
    new MiniCssExtractPlugin({
      filename: '[name].css',
    }),
  ],
}
