<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */


defined( 'ABSPATH' ) || exit;
require_once dirname( __FILE__ ) . '/' . '../inc/image-url-to-id.php';

get_header( 'shop' );

$shop_enabled = get_option('sonax_shop_enabled');

$new_products_category_id = get_option('sonax_new_products_category_id');

$is_category_page = is_product_category();
$show_stage = false;
$stage_data = null;
$is_child_category = false;



if ($is_category_page) {
  $term = get_queried_object();

  if ($term->parent !== 0) {
    $is_child_category = true;
  }

  
  $show_stage = get_field('show_stage', $term);
  $stage_data = get_field('stage', $term);

  $seo_text = get_field('seo_text', $term);
}

$all_product_categories = get_terms( 'product_cat' );

function sort_by_menu_order($a, $b) {
  if ($a->menu_order == $b->menu_order) {
      return 0;
  }
  return ($a->menu_order < $b->menu_order) ? -1 : 1;
}
?>

<?php if ($is_category_page) : ?>
  <?php if ($show_stage) : ?>
    <div class="snx-stage snx-stage--in-grid <?php if ($stage_data['invert_stage']): ?>snx-stage--is-invert<?php endif; ?>">
      <div class="snx-stage__bg-image">
        <picture class="">
          
          <?php
            $stage_img = $stage_data['image']['sizes'];

            $fallback_img_src = $stage_img['large'];

            $markup = "";
            
            $image_id = image_url_to_id($fallback_img_src);

            $urlStageImageBrp0 = wp_get_attachment_image_src($image_id, '480x480');
            $urlStageImageBrp1 = wp_get_attachment_image_src($image_id, '768x512');
            $urlStageImageBrp2 = wp_get_attachment_image_src($image_id, '992x426');
            $urlStageImageBrp3 = wp_get_attachment_image_src($image_id, '1200x515');
            $urlStageImageBrp4 = wp_get_attachment_image_src($image_id, '1920x823');
            
            if ($urlStageImageBrp0) {
                $markup .= "<source media='(max-width: 479px)' srcset='$urlStageImageBrp0[0]' />";
            }

            if ($urlStageImageBrp1) {
                $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$urlStageImageBrp0[1]' />";
            }

            if ($urlStageImageBrp1) {
                $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$urlStageImageBrp1[0]' />";
            }
            
            if ($urlStageImageBrp3) {
                $markup .= "<source media='(min-width: 992px) and (max-width: 1199px)' srcset='$urlStageImageBrp3[0]' />";
            }

            if ($urlStageImageBrp4) {
                $markup .= "<source media='(min-width: 1200px)' srcset='$urlStageImageBrp4[0]' />";
            }

            echo $markup;
          ?>
          <img alt="<?php echo $stage_data['image']['alt']; ?>" src="<?php echo $fallback_img_src; ?>" />
        </picture>
      </div>
      <div class="snx-stage__body">
        
        <h1 class="snx-stage__headline snx-loop__0">
          <?php echo $stage_data['title']; ?>
        </h1>
      </div>

      <?php if (!empty($stage_data['featured_image'])) : ?>
        <div class="snx-stage__featured-image">
          <picture class="">

            <?php

              $featured_image = $stage_data['featured_image']['sizes'];
              $fallback_featured_img_src = $featured_image['large'];

               $featured_image_id = image_url_to_id($fallback_featured_img_src);

              $markup = "";

                $urlFeaturedImageBrp0 = wp_get_attachment_image_src($featured_image_id, 'AUTOx330');
                $urlFeaturedImageBrp1 = wp_get_attachment_image_src($featured_image_id, 'AUTOx240');
                $urlFeaturedImageBrp2 = wp_get_attachment_image_src($featured_image_id, 'AUTOx300');
                $urlFeaturedImageBrp3 = wp_get_attachment_image_src($featured_image_id, 'AUTOx350');
                $urlFeaturedImageBrp4 = wp_get_attachment_image_src($featured_image_id, 'AUTOx700');
                
                if ($urlFeaturedImageBrp0) {
                    $markup .= "<source media='(max-width: 479px)' srcset='$urlFeaturedImageBrp0[0]' />";
                }

                if ($urlFeaturedImageBrp1) {
                    $markup .= "<source media='(min-width: 480px) and (max-width: 767px)' srcset='$urlFeaturedImageBrp1[0]' />";
                }
                
                if ($urlFeaturedImageBrp2) {
                    $markup .= "<source media='(min-width: 768px) and (max-width: 991px)' srcset='$urlFeaturedImageBrp2[0]' />";
                }

                if ($urlFeaturedImageBrp3) {
                    $markup .= "<source media='(min-width: 992x) and (max-width: 1199px)' srcset='$urlFeaturedImageBrp3[0]' />";
                }

                if ($urlFeaturedImageBrp4) {
                    $markup .= "<source media='(min-width: 1200px)' srcset='$urlFeaturedImageBrp4[0]' />";
                }

              echo $markup;
            ?>

            <img alt="<?php echo $stage_data['featured_image']['alt']; ?>" src="<?php echo $fallback_featured_img_src; ?>" />
          </picture>
      </div>
      <?php endif; ?>
    </div>


  <?php else : ?>
    <div class="snx-page-header snx-page-header--in-grid">
      <div class="snx-page-header__wrapper">
        <h1 class="snx-page-header__headline"><?php single_cat_title(); ?></h1>
      </div>
    </div>
  <?php endif; ?>
<?php endif; ?>

<div class="snx-util-rhythm-xl" id="listing">
  <?php if ($is_category_page && !empty(category_description())): ?>
  <section class="snx-page-section">
    <div class="snx-page-section__header"></div>
    <div class="snx-page-section__body">
        <div class="snx-util-block">
            <div class="snx-block-text">
                <p class="snx-font-body-01"><?php echo category_description(); ?></p>
            </div>
        </div>
    </div>
  </section>

  <?php endif; ?>

  <section class="snx-page-section">
    <div class="snx-page-section__body">
        <div class="snx-product-listing snx-product-listing--has-categories <?php if ($shop_enabled) : ?>snx-product-listing--has-prices<?php endif; ?>" >
        <div class="snx-product-listing__header">
          <?php if ($is_child_category) : ?>
            <a class="snx-btn snx-btn--default snx-btn--icon" href="<?php echo get_category_link( $term->parent ); ?>#listing">
              <svg class="snx-icon" viewBox="0 0 32 32">
                <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_left"></use>
              </svg>
            </a>
          <?php endif; ?>
          <h2 class="snx-font-subtitle-01"><?php single_cat_title(); ?></h2>
          <div class="snx-product-listing__mobile-tagbar">
            <?php if (!$is_category_page) : ?>
              <?php foreach($all_product_categories as $category) : ?>
                <?php
                  if ($category->parent !== 0) {
                    continue;
                  }
                ?>
                <a href="<?php echo get_category_link( $category->term_id ); ?>#listing" class="snx-tag"><?php echo $category->name; ?></a>
              <?php endforeach; ?>
            <?php elseif (!$is_child_category) : ?>
              <?php
                $category_children = get_term_children($term->term_id, 'product_cat');
              ?>
              <?php foreach($category_children as $category_child_id) : ?>
                <?php
                  $child_category = get_term($category_child_id, 'product_cat');
                ?>
                <a href="<?php echo get_category_link( $child_category->term_id ); ?>#listing" class="snx-tag"><?php echo $child_category->name; ?></a>
              <?php endforeach; ?>
            <?php endif; ?>
          </div>
        </div>

        <div class="snx-product-listing__sitebar">
          <ul class="snx-product-listing__categories">
            <?php foreach($all_product_categories as $category) : ?>
              <?php
                if ($category->parent !== 0) {
                  continue;
                }
                $category_children = get_term_children($category->term_id, 'product_cat');
              ?>
              <li class="snx-product-listing__categorie-item" data-level="0">
                <a href="<?php echo get_category_link( $category->term_id ); ?>">
                  <div class="snx-product-listing__categorie-label">
                    <?php echo $category->name; ?>
                  </div>
                   <?php if (!empty($category_children)) : ?>
                      <div class="snx-product-listing__categorie-toggle">
                        <svg class="snx-icon" viewBox="0 0 32 32"><use <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_plus"></use></svg>
                        <svg class="snx-icon" viewBox="0 0 32 32"><use <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_minus"></use></svg>
                      </div>
                   <?php endif; ?>
                </a>
                <?php
                  if (!empty($category_children)) :
                ?>
                  <?php
                    // fetch all child categories into an array
                    // fetch all child categories meta objects
                    // add the order meta value as key to the category object
                    // order the array by the value of menu_order
                    $category_children_objects = [];

                    foreach($category_children as $category_child_id) {
                      $category_child_object = get_term($category_child_id, 'product_cat');
                      $cateory_child_meta_object = get_term_meta($category_child_id);

                      if ($cateory_child_meta_object['order']) {
                        $category_child_object->menu_order = intval($cateory_child_meta_object['order'][0]);
                      } else {
                        $category_child_object->menu_order = 0;
                      }

                      array_push($category_children_objects, $category_child_object);
                    }

                    

                    usort($category_children_objects, "sort_by_menu_order");                  
                  ?>
                  <ul class="snx-product-listing__categories">
                    <?php foreach($category_children_objects as $child_category) : ?>
                      <li class="snx-product-listing__categorie-item" data-level="1">
                        <a href="<?php echo get_category_link( $child_category->term_id ); ?>">
                          <div class="snx-product-listing__categorie-label">
                            <?php echo $child_category->name; ?>
                          </div>
                        </a>
                      </li>
                    <?php endforeach; ?>
                  </ul>
                <?php endif; ?>
              </li>
            <?php endforeach; ?>
          </ul>
        </div>

        <script>

          function handleActiveLinks () {
            var listingSidebarItemActiveClass = 'snx-product-listing__categorie-item--active'

            Array.from(document.querySelectorAll('.snx-product-listing__categorie-item a')).forEach(function (listItemAnchor) {
              var listItem = listItemAnchor.parentElement
              listItem.classList.remove(listingSidebarItemActiveClass)

              const cleanCurrentHref = window.location.protocol + '//' + window.location.host + window.location.pathname

              if (listItemAnchor.getAttribute('href') === cleanCurrentHref) {
                listItem.classList.add(listingSidebarItemActiveClass)

                if (listItem.getAttribute('data-level') === '1') {
                  listItem.closest('.snx-product-listing__categorie-item[data-level="0"]').classList.add(listingSidebarItemActiveClass)
                }
              }
            })
          }

          document.addEventListener('DOMContentLoaded', function () {
            handleActiveLinks()

            document.addEventListener('resize', handleActiveLinks)
          })
        </script>

        <div class="snx-product-listing__body">
          <?php
            if ( woocommerce_product_loop() ) {
              if ( wc_get_loop_prop( 'total' ) ) {
                while ( have_posts() ) {
                  the_post();
                  global $product;
                  global $post;

                  if ( ! is_object( $product)) $product = wc_get_product( get_the_ID() );

                  /**
                   * Hook: woocommerce_shop_loop.
                   */
                  do_action( 'woocommerce_shop_loop' );


                  /* Set the product to default product from the loop */
                  $the_product = $product;

                  $product_categories = get_the_terms( $post->ID, 'product_cat' );
                  $product_is_in_category_new = false;

                  if (!empty($product_categories)) {
                    foreach ($product_categories as $key => $value) {
                      if ($value->term_id == $new_products_category_id) {
                        $product_is_in_category_new = true;
                        break;
                      }
                    }
                  }

                  /*
                    If the product is variable try to retrieve a default variation to show
                    the default variation in the listing instead of the parent product
                  */
                  if( $product->is_type('variable') ){
                      $default_attributes = $product->get_default_attributes();
                      foreach($product->get_available_variations() as $variation_values ){
                          foreach($variation_values['attributes'] as $key => $attribute_value ){
                              $attribute_name = str_replace( 'attribute_', '', $key );
                              $default_value = $product->get_variation_default_attribute($attribute_name);
                              if( $default_value == $attribute_value ){
                                  $is_default_variation = true;
                              } else {
                                  $is_default_variation = false;
                                  break; // Stop this loop to start next main lopp
                              }
                          }
                          if( $is_default_variation ){
                              $variation_id = $variation_values['variation_id'];
                              break; // Stop the main loop
                          }
                      }

                      // Now we get the default variation data
                      if( $is_default_variation ){
                          // Get the "default" WC_Product_Variation object to use available methods
                          $the_product = wc_get_product($variation_id);
                      }
                  }

                  $img_brp_0 = wp_get_attachment_image_src($the_product->get_image_id(), '293x195');
                  $img_brp_0_2x = wp_get_attachment_image_src($the_product->get_image_id(), '600x400');
                  
                  $img_brp_1 = wp_get_attachment_image_src($the_product->get_image_id(), '293x195');
                  $img_brp_1_2x = wp_get_attachment_image_src($the_product->get_image_id(), '600x400');
                  
                  $img_brp_2 = wp_get_attachment_image_src($the_product->get_image_id(), '375x250');
                  $img_brp_2_2x = wp_get_attachment_image_src($the_product->get_image_id(), '750x500');
                  
                  $img_brp_3 = wp_get_attachment_image_src($the_product->get_image_id(), '293x195');
                  $img_brp_3_2x = wp_get_attachment_image_src($the_product->get_image_id(), '600x400');
                  
                  $img_brp_4 = wp_get_attachment_image_src($the_product->get_image_id(), '293x195');
                  $img_brp_4_2x = wp_get_attachment_image_src($the_product->get_image_id(), '600x400');
                
                  $img_full = wp_get_attachment_image_src($the_product->get_image_id(), 'full');


                    $sale_price = false;
                    $regular_price = sonax_custom_format_price($the_product->get_regular_price());
                    if( $product->is_on_sale() ) {
                        $sale_price = sonax_custom_format_price($the_product->get_sale_price());
                    }                



                  ?>
                    <a class="snx-product-box snx-is--color-profiline" href="<?php echo get_permalink( $the_product->get_id() ); ?>">
                      <div class="snx-product-box__wrapper">
                        <?php if ($product_is_in_category_new ) : ?>
                          <div class="snx-badge snx-badge--round snx-product-box__new"><?php echo __('NEW', 'sonax'); ?></div>
                        <?php endif; ?>

                        <?php if ($shop_enabled): ?>
                            <?php if ($sale_price): ?>
                                <div class="snx-badge snx-badge--round snx-product-box__discount">%</div>
                            <?php endif; ?>
                        <?php endif; ?>

                        <div class="snx-product-box__image">
                          <picture>
                            <source
                              media="(max-width: 479px)"
                              srcset="
                                <?php echo $img_brp_0[0]; ?> 1x
                                <?php if (isset($img_brp_0_2x[0])) : ?>
                                , <?php echo $img_brp_0_2x[0]; ?> 2x
                                <?php endif; ?>
                              "
                            />
                            <source
                              media="(min-width: 480px) and (max-width: 767px)"
                              srcset="
                                <?php echo $img_brp_1[0]; ?> 1x
                                <?php if (isset($img_brp_1_2x[0])) : ?>
                                , <?php echo $img_brp_1_2x[0]; ?> 2x
                                <?php endif; ?>
                              "
                            />
                            <source
                              media="(min-width: 768px) and (max-width: 991px)"
                              srcset="
                                <?php echo $img_brp_2[0]; ?> 1x
                                <?php if (isset($img_brp_2_2x[0])) : ?>
                                , <?php echo $img_brp_2_2x[0]; ?> 2x
                                <?php endif; ?>
                              "
                            />
                            <source
                              media="(min-width: 992px) and (max-width: 1199px)"
                              srcset="
                                <?php echo $img_brp_3[0]; ?> 1x
                                <?php if (isset($img_brp_3_2x[0])) : ?>
                                , <?php echo $img_brp_3_2x[0]; ?> 2x
                                <?php endif; ?>
                              "
                            />
                            <source
                              media="(min-width: 1200px) and (max-width: 1399px)"
                              srcset="
                                <?php echo $img_brp_4[0]; ?> 1x
                                <?php if (isset($img_brp_4_2x[0])) : ?>
                                , <?php echo $img_brp_4_2x[0]; ?> 2x
                                <?php endif; ?>
                              "
                            />
                            
                            <img
                              src="<?php echo $img_full[0]; ?>"
                            />
                          </picture>
                        </div>
                        <div class="snx-product-box__detail">
                          <!-- <div class="snx-badge snx-is--color-brand-secondary">
                            <?php // echo strip_tags(wc_get_product_category_list($the_product->get_id())); ?>
                          </div> -->
                          <div class="snx-product-box__title"><?php echo $the_product->get_name(); ?></div>

                            <?php if ($shop_enabled) : ?>

                                <?php if ($sale_price): ?>
                                    <div class="snx-product-box__price-wrapper">
                                        <div class="snx-price snx-price--small snx-price--discount snx-price--text-shadow">
                                            <span class="snx-price__value"><?php echo $regular_price; ?></span>
                                            <sup class="snx-price__currency"><?php echo get_woocommerce_currency_symbol(); ?></sup>
                                            <div class="snx-price__discount-wrapper">
                                                <?php /*
                                                    Newline (sometimes) leads to whitespace nodes in the markup
                                                    See: https://stackoverflow.com/a/60173376
                                                */?>
                                                <span class="snx-price__discount-value"><?php echo $sale_price; ?></span><!--
                                                --><sup class="snx-price__discount-currency"><?php echo get_woocommerce_currency_symbol(); ?></sup>
                                            </div>
                                        </div>
                                    </div>
                                <?php else: ?>
                                    <div class="snx-product-box__price-wrapper">
                                        <div class="snx-price snx-price--small snx-price--text-shadow">
                                            <?php /*
                                                Newline (sometimes) leads to whitespace nodes in the markup
                                                See: https://stackoverflow.com/a/60173376
                                            */?>
                                            <span class="snx-price__value"><?php echo $regular_price; ?></span><!--
                                            --><sup class="snx-price__currency"><?php echo get_woocommerce_currency_symbol(); ?></sup>
                                        </div>
                                    </div>
                                <?php endif; ?>

                            <?php endif; ?>

                        </div>
                      </div>
                    </a>

                  <?php
                }
              }
            } else {
              /**
               * Hook: woocommerce_no_products_found.
               *
               * @hooked wc_no_products_found - 10
               */
              do_action( 'woocommerce_no_products_found' );
            }
          ?>
        </div>
      </div>
    </div>
    <div class="snx-page-section__footer">
        <div class="snx-button-group snx-button-group--space-between">
        <?php 
          $next_posts_tag = get_next_posts_link(); 
          $prev_posts_tag = get_previous_posts_link(); 

          if ($next_posts_tag != NULL) {
            $dom_next = new DOMDocument();
            $dom_next->loadHTML($next_posts_tag);

            $tags = $dom_next->getElementsByTagName('a');

            $next = $tags[0]->getAttribute('href');
          }
          if ($prev_posts_tag != NULL) {
            $dom_prev = new DOMDocument();
            $dom_prev->loadHTML($prev_posts_tag);

            $tags = $dom_prev->getElementsByTagName('a');

            $prev = $tags[0]->getAttribute('href');
          }

          if (!empty($prev)):
        ?>
          <a class="snx-btn snx-btn--default snx-btn--icon-left" href="<?php echo $prev; ?>" style="margin-right: auto;">
            <svg class="snx-icon" viewBox="0 0 32 32">
              <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_left"></use>
            </svg>
            <span><?php echo __('Previous Page', 'sonax'); ?></span>
          </a>
        <?php endif;
          if (!empty($next)):
        ?>
          <a class="snx-btn snx-btn--default snx-btn--icon-right" href="<?php echo $next; ?>" style="margin-left: auto;">
            <svg class="snx-icon" viewBox="0 0 32 32">
              <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_right"></use>
            </svg>
            <span><?php echo __('Next Page', 'sonax'); ?></span>
          </a>
        <?php endif; ?>
          </div>
      </div>
  </section>

  <?php if ($is_category_page && !empty($seo_text)): ?>
  <section class="snx-page-section">
    <div class="snx-page-section__header"></div>
    <div class="snx-page-section__body">
        <div class="snx-util-block">
            <div class="snx-block-text">
                <p class="snx-font-body-01"><?php echo $seo_text; ?></p>
            </div>
        </div>
    </div>
  </section>

  <?php endif; ?>

</div>
<?php

get_footer( 'shop' );
