<?php
/**
 * Cart totals
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart-totals.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 2.3.6
 */

defined( 'ABSPATH' ) || exit;

?>
<div class="snx-table cart_totals <?php echo ( WC()->customer->has_calculated_shipping() ) ? 'calculated_shipping' : ''; ?>" style="width: 50%; min-width: min(100%, 500px); margin-left: auto; margin-right: 0px;">

    <?php
        // Check if action requires table footer
        ob_start();
        do_action( 'woocommerce_before_cart_totals' );

        $content = ob_get_contents();
        ob_end_clean();

        if (empty($content)) {
            // no markup needed
        } else {
            ?>
            <div class="snx-table__header">
                <?php echo $content; ?>
            </div>
            <?php
        }
    ?>

    <?php 
	    /* <h2><?php esc_html_e( 'Cart totals', 'woocommerce' ); ?></h2> */
    ?>

	<table cellspacing="0" class="snx-table__table shop_table shop_table_responsive" style="line-height: 28px;">

		<tr class="snx-table__row cart-subtotal">
			<th class="snx-table__head-cell"><?php esc_html_e( 'Subtotal', 'woocommerce' ); ?></th>
			<td class="snx-table__row-cell" data-title="<?php esc_attr_e( 'Subtotal', 'woocommerce' ); ?>">
                <div class="snx-table__row-cell-content">
                    <span class="snx-table__row-header-title"><?php esc_html_e( 'Subtotal', 'woocommerce' ); ?></span>
                    <?php wc_cart_totals_subtotal_html(); ?>
                </div>
            </th>
		</tr>

		<?php foreach ( WC()->cart->get_coupons() as $code => $coupon ) : ?>
			<tr class="snx-table__row cart-discount coupon-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
				<th class="snx-table__head-cell"><?php wc_cart_totals_coupon_label( $coupon ); ?></th>
				<td class="snx-table__row-cell" data-title="<?php echo esc_attr( wc_cart_totals_coupon_label( $coupon, false ) ); ?>">
                    <div class="snx-table__row-cell-content">
                        <span class="snx-table__row-header-title"><?php wc_cart_totals_coupon_label( $coupon ); ?></span>
                        <div>
                            <?php wc_cart_totals_coupon_html( $coupon ); ?>
                        </div>
                    </div>
                </td>
			</tr>
		<?php endforeach; ?>

		<?php if ( WC()->cart->needs_shipping() && WC()->cart->show_shipping() ) : ?>

			<?php do_action( 'woocommerce_cart_totals_before_shipping' ); ?>

			<?php wc_cart_totals_shipping_html(); ?>

			<?php do_action( 'woocommerce_cart_totals_after_shipping' ); ?>

		<?php elseif ( WC()->cart->needs_shipping() && 'yes' === get_option( 'woocommerce_enable_shipping_calc' ) ) : ?>

			<tr class="snx-table__row shipping">
				<th class="snx-table__head-cell"><?php esc_html_e( 'Shipping', 'woocommerce' ); ?></th>
				<td class="snx-table__row-cell" data-title="<?php esc_attr_e( 'Shipping', 'woocommerce' ); ?>">
                    <div class="snx-table__row-cell-content">
                        <span class="snx-table__row-header-title"><?php esc_html_e( 'Shipping', 'woocommerce' ); ?></span>
                        <?php woocommerce_shipping_calculator(); ?>
                    </div>
                </td>
			</tr>

		<?php endif; ?>

		<?php foreach ( WC()->cart->get_fees() as $fee ) : ?>
			<tr class="snx-table__row fee">
				<th class="snx-table__head-cell"><?php echo esc_html( $fee->name ); ?></th>
				<td class="snx-table__row-cell" data-title="<?php echo esc_attr( $fee->name ); ?>">
                    <div class="snx-table__row-cell-content">
                        <span class="snx-table__row-header-title"><?php echo esc_html( $fee->name ); ?></span>
                        <?php wc_cart_totals_fee_html( $fee ); ?>
                    </div>
                </td>
			</tr>
		<?php endforeach; ?>

		<?php
		if ( wc_tax_enabled() && ! WC()->cart->display_prices_including_tax() ) {
			$taxable_address = WC()->customer->get_taxable_address();
			$estimated_text  = '';

			if ( WC()->customer->is_customer_outside_base() && ! WC()->customer->has_calculated_shipping() ) {
				/* translators: %s location. */
				$estimated_text = sprintf( ' <small>' . esc_html__( '(estimated for %s)', 'woocommerce' ) . '</small>', WC()->countries->estimated_for_prefix( $taxable_address[0] ) . WC()->countries->countries[ $taxable_address[0] ] );
			}

			if ( 'itemized' === get_option( 'woocommerce_tax_total_display' ) ) {
				foreach ( WC()->cart->get_tax_totals() as $code => $tax ) { // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
					?>
					<tr class="snx-table__row tax-rate tax-rate-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
						<th class="snx-table__head-cell"><?php echo esc_html( $tax->label ) . $estimated_text; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></th>
						<td class="snx-table__row-cell" data-title="<?php echo esc_attr( $tax->label ); ?>">
                            <div class="snx-table__row-cell-content">
                                <span class="snx-table__row-header-title"><?php echo esc_html( $tax->label ) . $estimated_text; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
                                <?php echo wp_kses_post( $tax->formatted_amount ); ?>
                            </div>
                        </td>
					</tr>
					<?php
				}
			} else {
				?>
				<tr class="snx-table__row tax-total">
					<th class="snx-table__head-cell"><?php echo esc_html( WC()->countries->tax_or_vat() ) . $estimated_text; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></th>
					<td class="snx-table__row-cell" data-title="<?php echo esc_attr( WC()->countries->tax_or_vat() ); ?>">
                        <div class="snx-table__row-cell-content">
                            <span class="snx-table__row-header-title"><?php echo esc_html( WC()->countries->tax_or_vat() ) . $estimated_text; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
                            <?php wc_cart_totals_taxes_total_html(); ?>
                        </div>
                    </td>
				</tr>
				<?php
			}
		}
		?>

		<?php do_action( 'woocommerce_cart_totals_before_order_total' ); ?>

		<tr class="snx-table__row order-total">
			<th class="snx-table__head-cell"><?php esc_html_e( 'Total', 'woocommerce' ); ?></th>
			<td class="snx-table__row-cell" data-title="<?php esc_attr_e( 'Total', 'woocommerce' ); ?>">
                <div class="snx-table__row-cell-content">
                    <span class="snx-table__row-header-title"><?php esc_html_e( 'Total', 'woocommerce' ); ?></span>
                    <?php wc_cart_totals_order_total_html(); ?>
                </div>
            </td>
		</tr>

		<?php do_action( 'woocommerce_cart_totals_after_order_total' ); ?>

	</table>

    <?php
        // Check if action requires table footer
        ob_start();
        do_action( 'woocommerce_after_cart_totals' );

        $content = ob_get_contents();
        ob_end_clean();

        if (empty($content)) {
            // no markup needed
        } else {
            ?>
            <div class="snx-table__footer">
                <?php echo $content; ?>
            </div>
            <?php
        }
    ?>
</div>

<script>
    /* WooCommerce internal JS duplicates the "proceed to checkout" button after changing the shipment method for some reason. If there is more than one button we remote it. GG */
    $(document).ready(function () {
        $('body').on('updated_shipping_method', function () {
            if ($('.snx-wc-fix-after-shipping-method-changed').length > 1) {
                $('.snx-wc-fix-after-shipping-method-changed').first().remove()
            }
        })
    })
</script>

<style>
    #wcpay-payment-request-wrapper {
        flex: 1;
        margin: 0px !important;
        padding: 0px !important;
    }
    #wcpay-payment-request-button-separator {
        margin: 0px !important;
    }

    .snx-wc-proceed-to-checkout {
        display: flex; 
        justify-content: flex-end; 
        align-items: center; 
        gap: var(--spacer); 
        width: 50%; 
        min-width: min(100%, 500px); 
        margin-left: auto;
    }

    @media (max-width: 480px) {
        .snx-wc-proceed-to-checkout {
            flex-direction: column;
        }

        .snx-wc-proceed-to-checkout .wc-forward {
            width: 100%;
            justify-content: center;
        }

        #wcpay-payment-request-wrapper {
            width: 100%;
        }
    }
</style>

<div class="wc-proceed-to-checkout snx-wc-proceed-to-checkout snx-wc-fix-after-shipping-method-changed" style="">
    <?php do_action( 'woocommerce_proceed_to_checkout' ); ?>
</div>
