<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.0.1
 */


/**
 * 
 * Notes
 * 
 * Notices
 * 
 * https://wordpress.org/support/topic/changing-the-html-of-notices-in-woocommerce/
 * 
 * Not customizable, so either:
 *      - hide them completely
 *      - hide them, build a js hack that hooks into events and shows our own notification patterns
 * 
 * For now: hide them. See header.php#74
 * 
 */

defined( 'ABSPATH' ) || exit;

do_action( 'woocommerce_before_cart' ); ?>

<section class="snx-page-section">

    <div class="snx-page-section__header">
        <h2 class="snx-page-section__headline"><?php echo get_the_title(); ?></h2>
    </div>

    <div class="snx-page-section__body">
        <form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">


            <?php do_action( 'woocommerce_before_cart_table' ); ?>

            <div class="snx-table snx-table--mobile">

                <div class="snx-table__header">
                    <a href="<?php echo esc_url( wc_get_checkout_url() ); ?>" class="snx-btn snx-btn--primary checkout-button button alt wc-forward<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>">
                        <svg class="snx-icon" viewBox="0 0 32 32">
                            <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_right"></use>
                        </svg>
                        <span><?php esc_html_e( 'Proceed to checkout', 'woocommerce' ); ?></span>
                    </a>
                </div>

                <table class="shop_table shop_table_responsive cart woocommerce-cart-form__contents snx-table__table" cellspacing="0">
                    <thead class="snx-table__head">
                        <tr class="snx-table__row">
                            <th class="snx-table__head-cell product-thumbnail"><span class="screen-reader-text"><?php esc_html_e( 'Thumbnail image', 'woocommerce' ); ?></span></th>
                            <th class="snx-table__head-cell product-name"><?php esc_html_e( 'Product', 'woocommerce' ); ?></th>
                            <th class="snx-table__head-cell product-price"><?php esc_html_e( 'Price', 'woocommerce' ); ?></th>
                            <th class="snx-table__head-cell product-quantity"><?php esc_html_e( 'Quantity', 'woocommerce' ); ?></th>
                            <th class="snx-table__head-cell product-subtotal"><?php esc_html_e( 'Subtotal', 'woocommerce' ); ?></th>
                            <th class="snx-table__head-cell product-remove"><span class="screen-reader-text"><?php esc_html_e( 'Remove item', 'woocommerce' ); ?></span></th>
                        </tr>
                    </thead>
                    <tbody class="snx-table__body">
                        <?php do_action( 'woocommerce_before_cart_contents' ); ?>

                        <?php
                        foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                            $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                            $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                            if ($cart_item['variation_id'] !== 0) {
								$product_id = $cart_item['variation_id'];
							}

                            if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                                $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                                ?>
                                <tr class="snx-table__row woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

                                    
                                    <td class=" snx-table__row-cell product-thumbnail">
                                        <div class="snx-table__row-cell-content">
                                            <span class="snx-table__row-header-title"><?php esc_html_e( 'Thumbnail image', 'woocommerce' ); ?></span>
                                            <?php 
                                                $image = wp_get_attachment_image_src( get_post_thumbnail_id( $product_id ), 'single-post-thumbnail' );
                                            ?>
                                            <img src="<?php echo $image[0]; ?>">
                                        </div>
                                    </td>

                                    <td class="snx-table__row-cell product-name" data-title="<?php esc_attr_e( 'Product', 'woocommerce' ); ?>">
                                        <div class="snx-table__row-cell-content">
                                            <span class="snx-table__row-header-title"><?php esc_html_e( 'Product', 'woocommerce' ); ?></span>
                                            <?php
                                            if ( ! $product_permalink ) {
                                                echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;' );
                                            } else {
                                                echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a style="font-weight: bold; font-size: var(--font-body-02-font-size);" href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key ) );
                                            }

                                            do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );

                                            // Meta data.
                                            echo wc_get_formatted_cart_item_data( $cart_item ); // PHPCS: XSS ok.

                                            // Backorder notification.
                                            if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                                                echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'woocommerce' ) . '</p>', $product_id ) );
                                            }
                                            ?>
                                        </div>
                                    </td>

                                    <td class="snx-table__row-cell product-price" data-title="<?php esc_attr_e( 'Price', 'woocommerce' ); ?>">
                                        <div class="snx-table__row-cell-content">
                                            <span class="snx-table__row-header-title"><?php esc_html_e( 'Price', 'woocommerce' ); ?></span>
                                            <?php
                                                echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.
                                            ?>
                                        </div>
                                    </td>

                                    <td class="snx-table__row-cell product-quantity" data-title="<?php esc_attr_e( 'Quantity', 'woocommerce' ); ?>">
                                        <div class="snx-table__row-cell-content">
                                            <span class="snx-table__row-header-title"><?php esc_html_e( 'Quantity', 'woocommerce' ); ?></span>
                                            <div style="min-width:50px;display:flex">
                                                <?php
                                                if ( $_product->is_sold_individually() ) {
                                                    $product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
                                                } else {
                                                    $product_quantity = woocommerce_quantity_input(
                                                        array(
                                                            'input_name'   => "cart[{$cart_item_key}][qty]",
                                                            'input_value'  => $cart_item['quantity'],
                                                            'max_value'    => $_product->get_max_purchase_quantity(),
                                                            'min_value'    => '0',
                                                            'product_name' => $_product->get_name(),
                                                            'classes' => 'snx-form-text'
                                                        ),
                                                        $_product,
                                                        false
                                                    );
                                                }

                                                echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); // PHPCS: XSS ok.
                                                ?>
                                                <button type="submit" name="update_cart" value="<?php esc_attr_e( 'Update cart', 'woocommerce' ); ?>" class="snx-btn snx-btn--default snx-btn--icon snx-btn--icon-only">
                                                    <svg class="snx-icon" viewBox="0 0 32 32">
                                                        <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#arrows-clockwise"></use>
                                                    </svg>
                                                </button>
                                            </div>
                                        </div>
                                    </td>

                                    <td class="snx-table__row-cell product-subtotal" data-title="<?php esc_attr_e( 'Subtotal', 'woocommerce' ); ?>">
                                        <div class="snx-table__row-cell-content">
                                            <span class="snx-table__row-header-title"><?php esc_html_e( 'Subtotal', 'woocommerce' ); ?></span>
                                            <?php
                                                echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.
                                            ?>
                                        </div>
                                    </td>

                                    <td class="snx-table__row-cell product-remove">
                                        <div class="snx-table__row-cell-content">
                                            <span class="snx-table__row-header-title"></span>
                                            <div style="display:flex;gap:var(--spacer-20);justify-content:flex-end">
                                                <?php
                                                    echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                                                        'woocommerce_cart_item_remove_link',
                                                        sprintf(
                                                            '<a href="%s" aria-label="%s" data-product_id="%s" data-product_sku="%s" class="snx-btn snx-btn--link snx-btn--small"><svg class="snx-icon" viewBox="0 0 32 32"><use xlink:href="%s/assets/sprite.svg#snx_cross"></use></svg><span>%s</span></button>',
                                                            // '<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s">&times;</a>',
                                                            esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
                                                            esc_html__( 'Remove this item', 'woocommerce' ),
                                                            esc_attr( $product_id ),
                                                            esc_attr( $_product->get_sku() ),
                                                            get_template_directory_uri(),
                                                            esc_html__( 'Remove', 'sonax' ),
                                                        ),
                                                        $cart_item_key
                                                    );
                                                ?>
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                                <?php
                            }
                        }
                        ?>

                        <?php do_action( 'woocommerce_cart_contents' ); ?>
                        
                    </tbody>
                </table>

            </div>
            <div class="snx-rich-text snx-rich-text--is-block" style="padding: var(--spacer-20) !important;">

                <?php do_action( 'woocommerce_after_cart_contents' ); ?>

                <?php if ( wc_coupons_enabled() ) { ?>
                        <div class="coupon" style="display: flex; flex-direction: column; gap: var(--spacer-20); flex-basis: 100%; width: 50%; min-width: min(100%, 500px); margin-left: auto;">
                            <div class="snx-form-group">
                                <label class="snx-form-group__label" for="coupon_code"><?php esc_html_e( 'Coupon:', 'woocommerce' ); ?></label>
                                <div style="display: flex; gap: var(--spacer);">
                                    <input class="snx-form-text" type="text" name="coupon_code" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'woocommerce' ); ?>" /> 
                                    <button type="submit" class="snx-btn snx-btn--default snx-btn--small" name="apply_coupon" value="<?php esc_attr_e( 'Apply coupon', 'woocommerce' ); ?>">
                                        <span>
                                            <?php esc_attr_e( 'Apply coupon', 'woocommerce' ); ?>
                                        </span>
                                    </button>
                                </div>
                            </div>
                            
                            <?php do_action( 'woocommerce_cart_coupon' ); ?>
                        </div>
                <?php } ?>

                <?php
                    /* Unused update cart button, replaced by buttons next to quantity input */
                    /* <button type="submit" class="button<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="update_cart" value="<?php esc_attr_e( 'Update cart', 'woocommerce' ); ?>"><?php esc_html_e( 'Update cart', 'woocommerce' ); ?></button> */
                ?>   
                
                <?php do_action( 'woocommerce_cart_actions' ); ?>

                <?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>

                <?php do_action( 'woocommerce_after_cart_table' ); ?>

                 <?php do_action( 'woocommerce_before_cart_collaterals' ); ?>

                 <div class="cart-collaterals" style="display: flex; flex-direction: column; gap: var(--spacer-20); flex-basis: 100%;">
                    <?php
                        /**
                         * Cart collaterals hook.
                         *
                         * @hooked woocommerce_cross_sell_display
                         * @hooked woocommerce_cart_totals - 10
                         */
                        do_action( 'woocommerce_cart_collaterals' );
                    ?>
                </div>

                <?php do_action( 'woocommerce_after_cart' ); ?>
            </div>
        </form>

       

    </div>
    </div>
</section>
