<?php
/**
 * Checkout Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/form-checkout.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/* do_action( 'woocommerce_before_checkout_form', $checkout ); */

// If checkout registration is disabled and not logged in, the user cannot checkout.
if ( ! $checkout->is_registration_enabled() && $checkout->is_registration_required() && ! is_user_logged_in() ) {
	echo esc_html( apply_filters( 'woocommerce_checkout_must_be_logged_in_message', __( 'You must be logged in to checkout.', 'woocommerce' ) ) );
	return;
}

?>

<section class="snx-page-section">

    <div class="snx-page-section__header">
        <h2 class="snx-page-section__headline"><?php echo get_the_title(); ?></h2>
    </div>

    <div class="snx-page-section__body">
        <div class="snx-rich-text snx-rich-text--is-block" id="checkout-body">
            <form name="checkout" method="post" class="snx-form checkout woocommerce-checkout" action="<?php echo esc_url( wc_get_checkout_url() ); ?>" enctype="multipart/form-data">
                <div class="snx-form__body">
                    <?php if ( $checkout->get_checkout_fields() ) : ?>
                        <?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>
                        <?php do_action( 'woocommerce_checkout_billing' ); ?>
                        <?php do_action( 'woocommerce_checkout_shipping' ); ?>
                        <?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>
                    <?php endif; ?>

                    <?php do_action( 'woocommerce_after_checkout_form', $checkout ); ?>
                    <?php do_action( 'woocommerce_checkout_before_order_review_heading' ); ?>

                    <fieldset>
                        <h3 class="snx-font-heading-04" id="order_review_heading"><?php esc_html_e( 'Your order', 'woocommerce' ); ?></h3>
                    </fieldset>

                    <?php do_action( 'woocommerce_checkout_before_order_review' ); ?>
                    <?php do_action( 'woocommerce_checkout_order_review' ); ?>
                    <?php do_action( 'woocommerce_checkout_after_order_review' ); ?>
                </div>
            </form>

            <script>
                $(document.body).on('checkout_error', function() {

                    if ($('#sonax-woocommerce-error-hack').length > 0) {
                        $('#sonax-woocommerce-error-hack').remove()
                    }

                    setTimeout(() => {
                        if ($('.woocommerce-notices-wrapper ul').length > 0) {
                            var errorText = $('.woocommerce-notices-wrapper')[0].textContent
                            var errorElement = document.createElement('ul')
                            errorElement.setAttribute('id', 'sonax-woocommerce-error-hack')
                            var errorTextElement = document.createElement('li')
                            errorTextElement.innerHTML = errorText
                            errorElement.appendChild(errorTextElement)
                            $('#checkout-body').prepend(errorElement)
                        }
                    }, 500);
                }) 
            </script>
        </div>
    </div>
</section>
