<?php
/**
 * Review order table
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/review-order.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 5.2.0
 */

defined( 'ABSPATH' ) || exit;
?>
<!-- if the class "woocommerce-checkout-review-order-table" is not on the top element, the woocommerce javascript duplicates markup and nests snx-form-group > snx-form-group > table. GG -->
<div class="snx-form-group woocommerce-checkout-review-order-table">
    <div class="snx-table">
        <table class="shop_table snx-table__table">
            <thead class="sxn-table__head">
                <tr class="snx-table__row">
                    <th class="product-name snx-table__head-cell"><?php esc_html_e( 'Product', 'woocommerce' ); ?></th>
                    <th class="product-total snx-table__head-cell"><?php esc_html_e( 'Subtotal', 'woocommerce' ); ?></th>
                </tr>
            </thead>
            <tbody class="snx-table__body">
                <?php
                do_action( 'woocommerce_review_order_before_cart_contents' );
    
                foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                    $_product = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
    
                    if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_checkout_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                        ?>
                        <tr class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?> snx-table__row">
                            <td class="product-name snx-table__row-cell">
                                <?php echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) ) . '&nbsp;'; ?>
                                <?php echo apply_filters( 'woocommerce_checkout_cart_item_quantity', ' <span class="product-quantity">' . sprintf( '&times;&nbsp;%s', $cart_item['quantity'] ) . '</span>', $cart_item, $cart_item_key ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                                <?php echo wc_get_formatted_cart_item_data( $cart_item ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                            </td>
                            <td class="product-total snx-table__row-cell">
                                <?php echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                            </td>
                        </tr>
                        <?php
                    }
                }
    
                do_action( 'woocommerce_review_order_after_cart_contents' );
                ?>
    
                <tr class="cart-subtotal snx-table__row">
                    <td class="snx-table__row-cell"><strong><?php esc_html_e( 'Subtotal', 'woocommerce' ); ?></strong></th>
                    <td class="snx-table__row-cell"><?php wc_cart_totals_subtotal_html(); ?></td>
                </tr>
    
                <?php foreach ( WC()->cart->get_coupons() as $code => $coupon ) : ?>
                    <tr class="cart-discount coupon-<?php echo esc_attr( sanitize_title( $code ) ); ?> snx-table__row">
                        <td class="snx-table__row-cell"><?php wc_cart_totals_coupon_label( $coupon ); ?></th>
                        <td class="snx-table__row-cell"><?php wc_cart_totals_coupon_html( $coupon ); ?></td>
                    </tr>
                <?php endforeach; ?>
    
                <?php if ( WC()->cart->needs_shipping() && WC()->cart->show_shipping() ) : ?>
    
                    <?php do_action( 'woocommerce_review_order_before_shipping' ); ?>
    
                    <?php wc_cart_totals_shipping_html(); ?>
    
                    <?php do_action( 'woocommerce_review_order_after_shipping' ); ?>
    
                <?php endif; ?>
    
                <?php foreach ( WC()->cart->get_fees() as $fee ) : ?>
                    <tr class="fee snx-table__row">
                        <td class="snx-table__row-cell"><strong><?php echo esc_html( $fee->name ); ?></strong></th>
                        <td class="snx-table__row-cell"><?php wc_cart_totals_fee_html( $fee ); ?></td>
                    </tr>
                <?php endforeach; ?>
    
                <?php if ( wc_tax_enabled() && ! WC()->cart->display_prices_including_tax() ) : ?>
                    <?php if ( 'itemized' === get_option( 'woocommerce_tax_total_display' ) ) : ?>
                        <?php foreach ( WC()->cart->get_tax_totals() as $code => $tax ) : // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited ?>
                            <tr class="tax-rate tax-rate-<?php echo esc_attr( sanitize_title( $code ) ); ?> snx-table__row">
                                <td class="snx-table__row-cell"><strong><?php echo esc_html( $tax->label ); ?></strong></th>
                                <td class="snx-table__row-cell"><?php echo wp_kses_post( $tax->formatted_amount ); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else : ?>
                        <tr class="tax-total snx-table__row">
                            <td class="snx-table__row-cell"><strong><?php echo esc_html( WC()->countries->tax_or_vat() ); ?></strong></th>
                            <td class="snx-table__row-cell"><?php wc_cart_totals_taxes_total_html(); ?></td>
                        </tr>
                    <?php endif; ?>
                <?php endif; ?>
    
                <?php do_action( 'woocommerce_review_order_before_order_total' ); ?>
    
                <tr class="order-total snx-table__row">
                    <td class="snx-table__row-cell"><strong><?php esc_html_e( 'Total', 'woocommerce' ); ?></strong></th>
                    <td class="snx-table__row-cell"><?php wc_cart_totals_order_total_html(); ?></td>
                </tr>
    
                <?php do_action( 'woocommerce_review_order_after_order_total' ); ?>
    
            </tbody>
        </table>
    </div>
</div>