<?php
/**
 * Thankyou page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/thankyou.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.7.0
 */

defined( 'ABSPATH' ) || exit;
?>


<section class="snx-page-section">

    <div class="snx-page-section__header">
        <h2 class="snx-page-section__headline"><?php echo get_the_title(); ?></h2>
    </div>    

    <div class="snx-page-section__body">

        <div class="snx-rich-text snx-rich-text--is-block">

            <div class="woocommerce-order snx-util-rhythm-xl">

                <div class="snx-alert snx-alert--has-success  snx-spacer--mb-20">
                    <div class="snx-alert__icon">
                        <svg class="snx-icon" viewBox="0 0 32 32">
                            <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_check"></use>
                        </svg>
                    </div>
                    <div class="snx-alert__body">
                        <div class="snx-alert__lead"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', esc_html__( 'Thank you. Your order has been received.', 'woocommerce' ), $order ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></div>
                    </div>
                </div>

                <?php
                if ( $order ) :

                    do_action( 'woocommerce_before_thankyou', $order->get_id() );
                    ?>

                    <?php if ( $order->has_status( 'failed' ) ) : ?>

                        <p class="woocommerce-notice woocommerce-notice--error woocommerce-thankyou-order-failed"><?php esc_html_e( 'Unfortunately your order cannot be processed as the originating bank/merchant has declined your transaction. Please attempt your purchase again.', 'woocommerce' ); ?></p>

                        <p class="woocommerce-notice woocommerce-notice--error woocommerce-thankyou-order-failed-actions">
                            <a href="<?php echo esc_url( $order->get_checkout_payment_url() ); ?>" class="button pay"><?php esc_html_e( 'Pay', 'woocommerce' ); ?></a>
                            <?php if ( is_user_logged_in() ) : ?>
                                <a href="<?php echo esc_url( wc_get_page_permalink( 'myaccount' ) ); ?>" class="button pay"><?php esc_html_e( 'My account', 'woocommerce' ); ?></a>
                            <?php endif; ?>
                        </p>

                    <?php else : ?>

                        <!-- <p class="woocommerce-notice woocommerce-notice--success woocommerce-thankyou-order-received"></p> -->

                        <ul class="woocommerce-order-overview woocommerce-thankyou-order-details order_details" style="list-style-type:none;padding-left:0; max-width:320px">

                            <li class="woocommerce-order-overview__order order" style="display:flex;justify-content:space-between;padding:0px;">
                                <strong><?php esc_html_e( 'Order number', 'sonax' ); ?></strong>
                                <span><?php echo $order->get_order_number(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
                            </li>

                            <li class="woocommerce-order-overview__date date" style="display:flex;justify-content:space-between;padding:0px;">
                                <strong><?php esc_html_e( 'Date', 'sonax' ); ?></strong>
                                <span><?php echo wc_format_datetime( $order->get_date_created() ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
                            </li>

                            <?php if ( is_user_logged_in() && $order->get_user_id() === get_current_user_id() && $order->get_billing_email() ) : ?>
                                <li class="woocommerce-order-overview__email email" style="display:flex;justify-content:space-between;padding:0px;">
                                    <strong><?php esc_html_e( 'Email', 'sonax' ); ?></strong>
                                    <span><?php echo $order->get_billing_email(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
                                </li>
                            <?php endif; ?>

                            <li class="woocommerce-order-overview__total total" style="display:flex;justify-content:space-between;padding:0px;">
                                <strong><?php esc_html_e( 'Total', 'sonax' ); ?></strong>
                                <span><?php echo $order->get_formatted_order_total(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
                            </li>

                            <?php if ( $order->get_payment_method_title() ) : ?>
                                <li class="woocommerce-order-overview__payment-method method" style="display:flex;justify-content:space-between;padding:0px;">
                                    <strong><?php esc_html_e( 'Payment method', 'sonax' ); ?></strong>
                                    <span><?php echo wp_kses_post( $order->get_payment_method_title() ); ?></span>
                                </li>
                            <?php endif; ?>

                        </ul>

                    <?php endif; ?>

                    <?php do_action( 'woocommerce_thankyou_' . $order->get_payment_method(), $order->get_id() ); ?>
                    <?php do_action( 'woocommerce_thankyou', $order->get_id() ); ?>

                <?php else : ?>

                    <p class="woocommerce-notice woocommerce-notice--success woocommerce-thankyou-order-received"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', esc_html__( 'Thank you. Your order has been received.', 'woocommerce' ), null ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>

                <?php endif; ?>

            </div>

            <a class="snx-btn snx-btn--primary" href="<?php echo get_permalink( wc_get_page_id( 'shop' ) ); ?>">
                <svg class="snx-icon" viewBox="0 0 32 32">
                    <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_right"></use>
                </svg>
                <span><?php echo __('Continue Shopping', 'sonax'); ?></span>
            </a>

        </div>
    </div>

</section>