<?php
/**
 * 
 * 
 * The Template for displaying all single products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce/Templates
 * @version     1.6.4
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
get_header();
get_header('shop');

the_post();

global $product;
global $post;
global $woocommerce;
if ( ! is_object( $product)) $product = wc_get_product( get_the_ID() );

$shop_enabled = get_option('sonax_shop_enabled');

$parent_product = $product;
$parent_product_id = $product->get_id();

$request_attributes = [];
$selected_variant_description = false;
$product_id = false;
$product_is_variant = false;
$is_default_variation = false;


if( $parent_product->is_type( 'variable' ) ) {
  foreach ( $product->get_variation_attributes() as $attribute_name => $options ) {
    if (isset( $_REQUEST[ 'attribute_' . sanitize_title( $attribute_name ) ] )) {
      $request_attributes['attribute_' . sanitize_title( $attribute_name )] = wc_clean( urldecode( $_REQUEST[ 'attribute_' . sanitize_title( $attribute_name ) ] ) );
    };
  };

  if (count($request_attributes) > 0) {
    $product_id = (new \WC_Product_Data_Store_CPT())->find_matching_product_variation(
        new \WC_Product($parent_product_id),
        $request_attributes
    );
    $product_is_variant = true;
    $product = wc_get_product($product_id);

  } else {
    $default_attributes = $product->get_default_attributes();

    
    $variation_id = false;

    foreach($product->get_available_variations() as $variation_values ){
      foreach($variation_values['attributes'] as $key => $attribute_value ){
          $attribute_name = str_replace( 'attribute_', '', $key );
          $default_value = $product->get_variation_default_attribute($attribute_name);
          if( $default_value == $attribute_value ){
              $is_default_variation = true;
          } else {
              $is_default_variation = false;
              break; // Stop this loop to start next main lopp
          }
      }
      if( $is_default_variation ){
          $variation_id = $variation_values['variation_id'];
          break; // Stop the main loop
      }
    }

    // Now we get the default variation data
    if( $is_default_variation ){
        // Raw output of available "default" variation details data
        // echo '<pre>'; print_r($variation_values); echo '</pre>';

        // Get the "default" WC_Product_Variation object to use available methods
        $product = wc_get_product($variation_id);

        // Get The active price
    }
  };
}

if ($parent_product->is_type( 'variable' )) {
  if (get_field("product_usage", $product->get_id())) { 
    $product_usage = get_field("product_usage", $product->get_id());
  } else {
    $product_usage = get_field("product_usage", $parent_product_id);
  }
} else {
  $product_usage = get_field("product_usage", $product->get_id());
}

if ($parent_product->is_type( 'variable' )) {
  if (get_field("product_video", $product->get_id())) {
    $product_video = get_field("product_video", $product->get_id());
  } else {
    $product_video = get_field("product_video", $parent_product_id);
  }
} else {
  $product_video = get_field("product_video", $product->get_id());
}

if ($parent_product->is_type( 'variable' )) {
  if (get_field("product_webshops", $product->get_id())) {
    $product_webshops = get_field("product_webshops", $product->get_id());
  } else {
    $product_webshops = get_field("product_webshops", $parent_product_id);
  }
} else {
  $product_webshops = get_field("product_webshops", $product->get_id());
}

$check_has_product_webshops = !is_null($product_webshops) && !empty($product_webshops);

$available_variations = null;

if ($parent_product->is_type( 'variable' )) {
  $available_variations = $parent_product->get_available_variations();
}

$new_products_category_id = get_option('sonax_new_products_category_id');
$product_categories = get_the_terms( $post->ID, 'product_cat' );
$product_is_in_category_new = false;

foreach ($product_categories as $key => $value) {
  if ($value->term_id == $new_products_category_id) {
    $product_is_in_category_new = true;
    break;
  }
}

$check_has_locations_query_args = array( 'post_type' => 'location', 'posts_per_page' => 100 ,'category_name'=>'reseller');
$check_has_locations_query = new WP_Query( $check_has_locations_query_args );
$check_has_locations = $check_has_locations_query->have_posts();

$gmaps_api_key = get_option('sonax_gmaps_api_key');

$render_locations = $check_has_locations && !empty($gmaps_api_key);

// Main product image

$main_img_brp_0 = wp_get_attachment_image_src($product->get_image_id(), '375x250');
$main_img_brp_0_2x = wp_get_attachment_image_src($product->get_image_id(), '750x500');

$main_img_brp_1 = wp_get_attachment_image_src($product->get_image_id(), '375x250');
$main_img_brp_1_2x = wp_get_attachment_image_src($product->get_image_id(), '750x500');

$main_img_brp_2 = wp_get_attachment_image_src($product->get_image_id(), '600x400');
$main_img_brp_2_2x = wp_get_attachment_image_src($product->get_image_id(), '1290x860');

$main_img_brp_3 = wp_get_attachment_image_src($product->get_image_id(), '675x450');
$main_img_brp_3_2x = wp_get_attachment_image_src($product->get_image_id(), '1350x900');

$main_img_brp_4 = wp_get_attachment_image_src($product->get_image_id(), '863x575');
$main_img_brp_4_2x = wp_get_attachment_image_src($product->get_image_id(), '1635x1090');

$main_img_brp_5 = wp_get_attachment_image_src($product->get_image_id(), '863x575');
$main_img_brp_5_2x = wp_get_attachment_image_src($product->get_image_id(), '1725x1150');

$main_img_full = wp_get_attachment_image_src($product->get_image_id(), 'full');
$main_img_thumbnail = wp_get_attachment_image_src($product->get_image_id(), '293x195');

// Gallery images

$gallery_attachment_ids = $parent_product->get_gallery_image_ids();
function check_products_are_not_all_empty($ids) {
  // If none of the ids can be resolved to a product, return false
  $result = false;

  // Go over each id
  foreach($ids as $id) {
    // Try to retrieve a product for it
    $potential_product = wc_get_product($id);

    // If the product is not false (hence can be resolved)
    if ($potential_product) {
      // Set result to tru
      $result = true;
      // And break the loop
      break;
    }
  }

  return $result;
}

?>

<script>
    <?php if (!empty($variation_id)): ?>
        window.SNX_WC_PRODUCT_ID = "<?php echo $variation_id; ?>";
    <?php elseif (!empty($product_id)): ?>
        window.SNX_WC_PRODUCT_ID = "<?php echo $product_id; ?>";
    <?php elseif (!empty($parent_product_id)): ?>
        window.SNX_WC_PRODUCT_ID = "<?php echo $parent_product_id; ?>";
    <?php endif; ?>
</script>

<div class="snx-notification snx-notification--boxed snx-hide" id="add-to-cart-notification-success">
    <div class="snx-notification__wrapper">
        <div class="snx-notification__body">
            <div class="snx-notification__body-wrapper">
                <p><?php echo __('The product has been added to the cart', 'sonax'); ?></p>
                <a class="snx-btn snx-btn--primary" href="<?php echo wc_get_cart_url(); ?>">
                    <svg class="snx-icon" viewBox="0 0 32 32">
                        <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_right"></use>
                    </svg>
                    <span><?php echo __('View cart', 'sonax'); ?></span>
                </a>
            </div>
        </div>
    </div>
</div>

<div class="snx-notification snx-notification--boxed snx-notification--loud snx-notification--error snx-hide" id="add-to-cart-notification-failure">
  <div class="snx-notification__wrapper">
    <div class="snx-notification__body">
      <span class="snx-notification__error-icon">
        <svg class="snx-icon" viewBox="0 0 32 32">
          <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_cross_box"></use>
        </svg>
      </span>
      <div class="snx-notification__body-wrapper">
        <p><?php echo __('Something went wrong, please try again.', 'sonax'); ?></p>
        <button class="snx-btn snx-btn--primary">
          <svg class="snx-icon" viewBox="0 0 32 32">
            <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_right"></use>
          </svg>
          <span onclick="window.location.reload()"><?php echo __('Close', 'sonax'); ?></span>
        </button>
      </div>
    </div>
  </div>
</div>

<div class="snx-util-rhythm-xl">

  <section class="snx-product-detail">
    <div class="snx-product-detail__wrapper">
      <div class="snx-product-detail__body">

        <!-- <div class="snx-product-detail__body-zoom-container"></div> -->

        <div class="snx-product-detail__body-content">
          <div class="snx-product-detail__details">
            <!-- <div class="snx-product-detail__details-badge">
              <div class="snx-badge snx-is--color-interior">Innenraum &amp; Scheibe</div>
              <div class="snx-product-detail__details-badge-award">
                <svg class="snx-icon snx-product-detail__details-badge-award-icon" viewBox="0 0 32 32">
                  <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_trophy"></use>
                </svg>
                <span class="snx-product-detail__details-badge-award-label">Testsieger</span>
              </div
            </div> -->
            <h1 class="snx-product-detail__details-title"><?php echo $product->get_name(); ?></h1>

            <?php if ($shop_enabled) : ?>

                <?php
                    $sale_price = false;
                    // $regular_price = number_format_i18n((float)$product->get_regular_price(), 2);
                    $regular_price = sonax_custom_format_price($product->get_regular_price());
                    if( $product->is_on_sale() ) {
                        // $sale_price = number_format_i18n((float)$product->get_sale_price(), 2);
                        $sale_price = sonax_custom_format_price($product->get_sale_price());
                    }                
                ?>

                <?php if ($sale_price): ?>
                    <div class="snx-product-detail__details-price">
                        <div class="snx-price snx-price--discount snx-price--text-shadow">
                            <span class="snx-price__value"><?php echo $regular_price; ?></span>
                            <sup class="snx-price__currency"><?php echo get_woocommerce_currency_symbol(); ?></sup>
                            <div class="snx-price__discount-wrapper">
                                <?php /*
                                    Newline (sometimes) leads to whitespace nodes in the markup
                                    See: https://stackoverflow.com/a/60173376
                                */?>
                                <span class="snx-price__discount-value"><?php echo $sale_price; ?></span><!--
                                --><sup class="snx-price__discount-currency"><?php echo get_woocommerce_currency_symbol(); ?></sup>
                            </div>
                        </div>
                    </div>
                <?php else: ?>
                    <div class="snx-product-detail__details-price">
                        <div class="snx-price snx-price--text-shadow">
                            <?php /*
                                Newline (sometimes) leads to whitespace nodes in the markup
                                See: https://stackoverflow.com/a/60173376
                            */?>
                            <span class="snx-price__value"><?php echo $regular_price; ?></span><!--
                            --><sup class="snx-price__currency"><?php echo get_woocommerce_currency_symbol(); ?></sup>
                        </div>
                    </div>
                <?php endif; ?>

            <?php endif; ?>
            
            <div class="snx-product-detail__details-interaction">
              <!-- Variants selection -->
              <?php if( $parent_product->is_type( 'variable' ) && count($available_variations ) > 1): ?>

                <div class="snx-product-detail__details-sizes">
                  <span class="snx-product-detail__details-sizes-label"><?php echo __('Variants: ', 'sonax') ?></span>
                  <div class="snx-dropdown">
                    <button class="snx-dropdown__button snx-dropdown__toggle">
                      <span class="snx-dropdown__label">
                        <?php
                          $available_variations = $parent_product->get_available_variations();
                          foreach ($available_variations as $key => $value) :
                        ?>
                          <?php if ($value['variation_id'] == $product->get_id()) {
                            $product_variation = wc_get_product($value['variation_id']);
                            $attributes = array();
                            foreach( $value['attributes'] as $key => $value ){
                                $taxonomy = str_replace('attribute_', '', $key );
                                $attributes[] = $value; // $taxonomy_label.': '.$term_name;
                            }
                            echo implode( ' | ', $attributes );

                          }?>
                        <?php endforeach; ?>
                        <?php if (!$is_default_variation && !$product_is_variant) {
                          echo __('Select a variant...', 'sonax');
                        }?>
                      </span>
                      <svg class="snx-dropdown__arrow" viewBox="0 0 32 32">
                        <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_down"></use>
                      </svg>
                    </button>
                    <div class="snx-dropdown__content snx-dropdown__nav">
                      <ul>
                        <?php
                          foreach ($available_variations as $key => $value) :
                        ?>
                          <?php $product_variation = wc_get_product($value['variation_id']); ?>
                          <?php if ($value['variation_id'] !== $product->get_id()) : ?>
                            <li>
                              <a href="<?php echo wc_get_product($value['variation_id'])->get_permalink(); ?>">
                                <?php
                                  $attributes = array();
                                  foreach( $value['attributes'] as $key => $value ){
                                      $taxonomy = str_replace('attribute_', '', $key );
                                      $attributes[] = $value; // $taxonomy_label.': '.$term_name;
                                  }
                                  echo implode( ' | ', $attributes );
                                ?>
                              </a>
                            </li>
                          <?php endif; ?>
                        <?php endforeach; ?>
                      </ul>
                    </div>
                  </div>
                </div>

              <?php elseif (!empty($product->get_attributes())) : ?>
              <?php
                $attributes_object = null;

                if ($parent_product) {
                  $attributes_object = $parent_product->get_attributes();
                } else {
                  $attributes_object = $product->get_attributes();
                }


                $attributes = reset($attributes_object);

                $attribute_name = $attributes['data']['name'];
                $attribute_value = $attributes['data']['options'][0];

                $attribute_i18n_name = "";

                if ($attribute_name === 'Volume') {
                  $attribute_i18n_name = __('Volume', 'sonax');
                } else {
                  $attribute_i18n_name = $attribute_name;
                }

              ?>

                <div class="snx-product-detail__details-sizes">
                  <span class="snx-product-detail__details-sizes-label"><?php echo $attribute_i18n_name; ?>: <?php echo $attribute_value; ?></span>
                </div>

              <?php endif ?>

              <div class="snx-product-detail__details-sku"><?php echo __('SKU:', 'sonax') ?>&nbsp;<?php echo $product->get_sku(); ?></div>
            </div>

            <?php if ($shop_enabled): ?>
                <?php
                    $product_not_available = false;
                    $prodcut_on_backorder = false;

                    if ($product->get_manage_stock()) {
                        if($product->get_stock_quantity()>0) {
                            $product_not_available = false;
                        } else {
                            if($product->backorders_allowed()) { 
                                $product_not_available = false;
                                $prodcut_on_backorder = true;
                            } else {
                                $product_not_available = true;
                            }
                        }
                    } else {
                        $product_not_available = false;
                    }
                ?>

                <?php
                    if ( $product->needs_shipping() ) {
                        if ( $product_not_available ) {
                            echo "<div class='snx-product-detail__details-shipping snx-product-detail__details-shipping--state-2'>";
                            echo __('Out of stock', 'sonax');
                            echo "</div>";
                        } else {
                            // $zones = WC_Shipping_Zones::get_zones();

                            // if ($prodcut_on_backorder) {
                            //     echo "<div class='snx-product-detail__details-shipping snx-product-detail__details-shipping--state-1'>";
                            //     echo get_option('sonax_shop_backorder_label', 'on backorder, delivery within 2 weeks');
                            //     echo "</div>";
                            // } else {
                            //     echo "<div class='snx-product-detail__details-shipping'>";
                            //     echo get_option('sonax_shop_delivery_label', 'In stock, delivery within 3 days');
                            //     echo "</div>";
                            // }

                            // Alternative: loop through all available shipping zones and methods
                            // foreach ( $zones as $zone_id => $zone ) {
                            //     $zone_shipping_methods = $zone['shipping_methods'];
                            //     echo __(', Shipping to ', 'sonax');
                            //     echo  $zone['zone_name'] . ': ';
                            //     foreach ( $zone_shipping_methods as $index => $method ) {
                            //         $instance = $method->instance_settings;
                            //         $cost = $instance['cost'] ? $instance['cost'] : $instance['min_amount'];
                            //          echo $instance['title'] . '&nbsp;' . wc_price( $cost );
                            //          if ($index < count($zone_shipping_methods)) {
                            //             echo ', ';
                            //          }
                            //     }
                            // }
                        }
                    }
                ?> 

                <!-- Buy modal trigger -->

                <div class="snx-product-detail__details-buy">
                    <button class="snx-btn snx-btn--primary snx-product-detail__details-buy-button" <?php if ($product_not_available): ?>disabled="disabled"<?php endif; ?> id="add-to-cart-main" >
                        <svg class="snx-icon" viewBox="0 0 32 32">
                            <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_right"></use>
                        </svg>
                        <div class="snx-btn-loading-spinner snx-hide">
                            <div class="snx-btn-loading-spinner__spinner"></div>
                        </div>
                        <span><?php echo __('Add to cart', 'sonax'); ?></span>
                    </button>
                </div>

            <?php endif; ?>

            <?php if ($render_locations || !!$check_has_product_webshops) : ?>
              <div class="snx-product-detail__details-buy">
                <a class="snx-btn snx-btn--default snx-product-detail__details-buy-button" href="#" data-modal-target="#buySelection">
                  <svg class="snx-icon" viewBox="0 0 32 32">
                    <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_chevron_right"></use>
                  </svg>
                  <span><?php echo __('Find Dealer', 'sonax'); ?></span>
                </a>
              </div>
            <?php endif ?>

            <!-- Short description -->
            <div class="snx-product-detail__details-excerpt"><?php echo wpautop($parent_product->get_short_description()); ?></div>


            <!-- Variation list 
            <div class="snx-product-detail__details-variation">
              <span class="snx-product-detail__details-variation-title">Weitere Düfte</span>
              <div class="snx-product-detail__details-variation-list">

                // Variation items, repeat for each variation 
                <a class="snx-product-detail__details-variation-list-item" href="#">
                  <span class="snx-product-detail__details-variation-list-item-image">
                    <img class="snx-product-detail__details-variation-list-item-image-asset" src="https://res.cloudinary.com/sonax-gmbh/image/fetch/c_fit,h_180,q_auto:eco/dpr_1,f_auto/https://www.sonax.de/var/site/storage/images/9/4/9/2/42949-2-ger-DE/03924410-SONAX-ScheibenReiniger-Cherry-Kick-3L-SSB.png" alt="Cherry Kick" />
                  </span>
                  <span class="snx-product-detail__details-variation-list-item-title">Cherry Kick</span>
                </a>

              </div>
            </div>
            -->
          </div>
        </div>
        <div class="snx-product-detail__body-image">
          <div class="snx-product-detail__gallery">
            <div class="snx-product-detail__gallery-main">
              <div class="snx-product-detail__gallery-main-image">
                <div class="snx-slider snx-slider--slider-gallery">
                  <div class="snx-slider__body">
                    <div class="snx-slider__container" data-glide-el="controls">
                      <div class="snx-slider__track-wrapper" data-glide-el="track">
                        <div class="snx-slider__track"> 
                          
                          <!-- Product gallery main image, repeat for each gallery item -->
                          <div class="snx-slider__slide" data-modal-target="#productImages">
                            <picture>
                              <source
                                media="(max-width: 479px)"
                                srcset="
                                  <?php echo $main_img_brp_0[0]; ?> 1x
                                  <?php if (isset($main_img_brp_0_2x[0])) : ?>
                                  , <?php echo $main_img_brp_0_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 480px) and (max-width: 767px)"
                                srcset="
                                  <?php echo $main_img_brp_1[0]; ?> 1x
                                  <?php if (isset($main_img_brp_1_2x[0])) : ?>
                                  , <?php echo $main_img_brp_1_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 768px) and (max-width: 991px)"
                                srcset="
                                  <?php echo $main_img_brp_2[0]; ?> 1x
                                  <?php if (isset($main_img_brp_2_2x[0])) : ?>
                                  , <?php echo $main_img_brp_2_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 992px) and (max-width: 1199px)"
                                srcset="
                                  <?php echo $main_img_brp_3[0]; ?> 1x
                                  <?php if (isset($main_img_brp_3_2x[0])) : ?>
                                  , <?php echo $main_img_brp_3_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 1200px) and (max-width: 1399px)"
                                srcset="
                                  <?php echo $main_img_brp_4[0]; ?> 1x
                                  <?php if (isset($main_img_brp_4_2x[0])) : ?>
                                  , <?php echo $main_img_brp_4_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 1400px)"
                                srcset="
                                  <?php echo $main_img_brp_5[0]; ?> 1x
                                  <?php if (isset($main_img_brp_5_2x[0])) : ?>
                                  , <?php echo $main_img_brp_5_2x[0]; ?> 2x
                                  <?php endif; ?> 
                                "
                              />
                              <img
                                src="<?php echo $main_img_full[0]; ?>"
                              />
                            </picture>
                          </div>

                          <?php foreach ($gallery_attachment_ids as $gallery_attachment_id) : ?>
                            <?php
                              $gallery_img_brp_0 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                              $gallery_img_brp_0_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                              $gallery_img_brp_1 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                              $gallery_img_brp_1_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                              $gallery_img_brp_2 = wp_get_attachment_image_src($gallery_attachment_id, '375x250');
                              $gallery_img_brp_2_2x = wp_get_attachment_image_src($gallery_attachment_id, '750x500');

                              $gallery_img_brp_3 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                              $gallery_img_brp_3_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                              $gallery_img_brp_4 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                              $gallery_img_brp_4_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                              $gallery_img_full = wp_get_attachment_image_src($gallery_attachment_id, 'full');  
                            ?>

                            <div class="snx-slider__slide" data-modal-target="#productImages">
                              <picture>
                                <source
                                  media="(max-width: 479px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_0[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_0_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_0_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                <source
                                  media="(min-width: 480px) and (max-width: 767px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_1[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_1_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_1_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                <source
                                  media="(min-width: 768px) and (max-width: 991px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_2[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_2_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_2_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                <source
                                  media="(min-width: 992px) and (max-width: 1199px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_3[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_3_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_3_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                <source
                                  media="(min-width: 1200px) and (max-width: 1399px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_4[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_4_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_4_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                
                                <img
                                  src="<?php echo $gallery_img_full[0]; ?>"
                                />
                              </picture>
                            </div>

                          <?php endforeach; ?>

                        </div>

                        <ul class="slick-dots" data-glide-el="controls[nav]">
                          <?php foreach ($gallery_attachment_ids as $index=>$gallery_attachment_id) : ?>
                            <li data-glide-dir="=<?php echo $index; ?>">
                              <button type="button">
                                <?php echo $index; ?>
                              </button>
                            </li>
                          <?php endforeach; ?>
                        </ul>

                      </div> 
                    </div>
                    <style>
                      .snx-slider .slick-dots {
                        display: flex !important;
                      }
                    </style>
                  </div>
                </div>
                <div class="snx-product-detail__gallery-main-image-pattern">
                  <img src="<?php echo get_template_directory_uri(); ?>/assets/sun.png" alt="" />
                </div>
              </div>
              <?php if ($product_is_in_category_new ) : ?>
                <aside class="snx-product-detail__gallery-main-aside">

                  <div class="snx-product-detail__gallery-main-aside-badge">
                    <div class="snx-badge snx-badge--round snx-badge--loud"><?php echo __('NEW', 'sonax'); ?></div>
                  </div>
                

                  <!-- 
                    <div class="snx-product-detail__gallery-main-aside-award">
                      <picture class="">
                        <img src="http://localhost:3001/static/images/responsive-images/award-80-1x.png" alt="Award image title" />
                      </picture>
                      <picture class="">
                        <img src="http://localhost:3001/static/images/responsive-images/award-80-1x.png" alt="Award image title" />
                      </picture>
                    </div>
                  -->
                </aside>
              <?php endif; ?>
            </div>

            <?php if (!empty($gallery_attachment_ids)) : ?>

              <div class="snx-product-detail__gallery-thumbnails">
                <div class="snx-slider snx-slider--slider-gallery-thumbnails">
                  <div class="snx-slider__body">
                    <div class="snx-slider__container" data-glide-el='controls'>
                      <div class="snx-slider__track-wrapper" data-glide-el="track">
                        <div class="snx-slider__track">

                          <!-- Product gallery thumbnails item, repeat for each gallery item -->
                          <div class="snx-slider__slide">
                            <picture>
                              <source
                                media="(max-width: 479px)"
                                srcset="
                                  <?php echo $main_img_brp_0[0]; ?> 1x
                                  <?php if (isset($main_img_brp_0_2x[0])) : ?>
                                  , <?php echo $main_img_brp_0_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 480px) and (max-width: 767px)"
                                srcset="
                                  <?php echo $main_img_brp_1[0]; ?> 1x
                                  <?php if (isset($main_img_brp_1_2x[0])) : ?>
                                  , <?php echo $main_img_brp_1_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 768px) and (max-width: 991px)"
                                srcset="
                                  <?php echo $main_img_brp_2[0]; ?> 1x
                                  <?php if (isset($main_img_brp_2_2x[0])) : ?>
                                  , <?php echo $main_img_brp_2_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 992px) and (max-width: 1199px)"
                                srcset="
                                  <?php echo $main_img_brp_3[0]; ?> 1x
                                  <?php if (isset($main_img_brp_3_2x[0])) : ?>
                                  , <?php echo $main_img_brp_3_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 1200px) and (max-width: 1399px)"
                                srcset="
                                  <?php echo $main_img_brp_4[0]; ?> 1x
                                  <?php if (isset($main_img_brp_4_2x[0])) : ?>
                                  , <?php echo $main_img_brp_4_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 1400px)"
                                srcset="
                                  <?php echo $main_img_brp_5[0]; ?> 1x
                                  <?php if (isset($main_img_brp_5_2x[0])) : ?>
                                  , <?php echo $main_img_brp_5_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <img
                                src="<?php echo $main_img_full[0]; ?>"
                              />
                            </picture>
                          </div>

                          <?php foreach ($gallery_attachment_ids as $gallery_attachment_id) : ?>
                            <?php
                              $gallery_img_brp_0 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                              $gallery_img_brp_0_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                              $gallery_img_brp_1 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                              $gallery_img_brp_1_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                              $gallery_img_brp_2 = wp_get_attachment_image_src($gallery_attachment_id, '375x250');
                              $gallery_img_brp_2_2x = wp_get_attachment_image_src($gallery_attachment_id, '750x500');

                              $gallery_img_brp_3 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                              $gallery_img_brp_3_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                              $gallery_img_brp_4 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                              $gallery_img_brp_4_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                              $gallery_img_full = wp_get_attachment_image_src($gallery_attachment_id, 'full');  
                            ?>

                            <div class="snx-slider__slide">
                              <picture>
                                <source
                                  media="(max-width: 479px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_0[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_0_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_0_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                <source
                                  media="(min-width: 480px) and (max-width: 767px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_1[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_1_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_1_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                <source
                                  media="(min-width: 768px) and (max-width: 991px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_2[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_2_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_2_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                <source
                                  media="(min-width: 992px) and (max-width: 1199px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_3[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_3_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_3_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                <source
                                  media="(min-width: 1200px) and (max-width: 1399px)"
                                  srcset="
                                    <?php echo $gallery_img_brp_4[0]; ?> 1x
                                    <?php if (isset($gallery_img_brp_4_2x[0])) : ?>
                                    , <?php echo $gallery_img_brp_4_2x[0]; ?> 2x
                                    <?php endif; ?>
                                  "
                                />
                                
                                <img
                                  src="<?php echo $gallery_img_full[0]; ?>"
                                  data-zoom-src="<?php echo $gallery_img_full[0]; ?>"
                                />
                              </picture>
                            </div>

                          <?php endforeach; ?>
                      
                        </div>
                      </div>

                      <button class="slick-next slick-arrow" aria-label="Next" type="button" aria-disabled="false" data-glide-dir=">">Next</button>
                      <button class="slick-prev slick-arrow" aria-label="Previous" type="button" aria-disabled="true" data-glide-dir="<">Previous</button>
                    </div>
                    <style>
                      .snx-slider .slick-dots {
                        display: flex !important;
                      }
                    </style>
                  </div>
                </div>
              </div>

            <?php endif; ?>
          </div>
        </div>
      </div>
    </div>
    <div class="snx-diagonal snx-product-detail__diagonal snx-is--color-brand-secondary"></div>
  </section>


  
  <?php if (!empty($parent_product->get_description())): ?>
    <section class="snx-page-section">
      <div class="snx-page-section__header"><h2 class="snx-page-section__headline"><?php echo __('Description', 'sonax'); ?></h2></div>
      <div class="snx-page-section__body">
        <div class="snx-util-block">
          <div class="snx-block-text">
            <div class="snx-rich-text snx-woocommerce-description">
              <?php echo wpautop($parent_product->get_description()); ?>
            </div>
          </div>
        </div>
      </div>
    </section>
  <?php endif; ?>

  <?php if ($product_usage): ?>
    <section id="usage" class="snx-page-section">
        <div class="snx-page-section__header">
            <h2 class="snx-page-section__headline"><?php echo __('Product Usage', 'sonax'); ?></h2>
        </div>
        <div class="snx-page-section__body">
            <div class="snx-block-content">
                <div class="snx-rich-text snx-rich-text--is-block snx-styled-list">
                    <ol>
                      <?php foreach($product_usage as $key => $step): ?>
                        <li class="regular"><?php echo $step['usage_step']; ?></li>
                      <?php endforeach; ?>
                    </ol>
                </div>
            </div>
        </div>
    </section>
  <?php endif; ?>

  <?php if ($product_video): ?>
    <?php
      $video_id = false;
      if (preg_match('%(?:youtube(?:-nocookie)?\.com/(?:[^/]+/.+/|(?:v|e(?:mbed)?)/|.*[?&]v=)|youtu\.be/)([^"&?/\s]{11})%i', $product_video, $match)) {
          $video_id = $match[1];
      }
      parse_str( parse_url( $product_video, PHP_URL_QUERY ), $youtube_url_params );
      $youtube_id = $youtube_url_params['v'];
      if ($video_id):
    ?>
      <section class="snx-page-section">
        <div class="snx-page-section__header">
            <h2 class="snx-page-section__headline">
                <?php echo __('Video', 'sonax'); ?>
            </h2>
        </div>
        <div class="snx-page-section__body">
          <div class="snx-video">
            <iframe
              src="https://www.youtube.com/embed/<?php echo $youtube_id; ?>"
              title="Anwendung SONAX PROFILINE Ceramic Coating CC Evo"
              frameborder="0"
              allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
              allowfullscreen=""
            ></iframe>
          </div>
        </div>
      </section>
    <?php endif; ?>
  <?php endif; ?>

  <?php
    $up_sell_ids = $product->get_upsell_ids();
    if (!empty($up_sell_ids) && check_products_are_not_all_empty($up_sell_ids)) :
  ?>

    <section class="snx-page-section">
      <div class="snx-page-section__header">
        <h2 class="snx-page-section__headline">
          <?php echo __('Related Products', 'sonax'); ?>
        </h2>
      </div>

      <div class="snx-page-section__body">
        <div class="snx-slider snx-slider--slider-product">
          <div class="snx-slider__body">
            <div class="snx-slider__container" data-glide-el="controls">

              <div class="snx-slider__track-wrapper" data-glide-el="track">
                <div class="snx-slider__track">

                  <?php 
                    foreach($up_sell_ids as $id) :
                    $up_sell_product = wc_get_product($id);

                    if (!$up_sell_product) {
                      continue;
                    }

                    $img_brp_0 = wp_get_attachment_image_src($up_sell_product->get_image_id(), '293x195');
                    $img_brp_0_2x = wp_get_attachment_image_src($up_sell_product->get_image_id(), '600x400');
                    
                    $img_brp_1 = wp_get_attachment_image_src($up_sell_product->get_image_id(), '293x195');
                    $img_brp_1_2x = wp_get_attachment_image_src($up_sell_product->get_image_id(), '600x400');
                    
                    $img_brp_2 = wp_get_attachment_image_src($up_sell_product->get_image_id(), '375x250');
                    $img_brp_2_2x = wp_get_attachment_image_src($up_sell_product->get_image_id(), '750x500');
                    
                    $img_brp_3 = wp_get_attachment_image_src($up_sell_product->get_image_id(), '293x195');
                    $img_brp_3_2x = wp_get_attachment_image_src($up_sell_product->get_image_id(), '600x400');
                    
                    $img_brp_4 = wp_get_attachment_image_src($up_sell_product->get_image_id(), '293x195');
                    $img_brp_4_2x = wp_get_attachment_image_src($up_sell_product->get_image_id(), '600x400');
                  
                    $img_full = wp_get_attachment_image_src($up_sell_product->get_image_id(), 'full');

                  ?>
                  
                    <div class="snx-slider__slide">
                      <a class="snx-product-box snx-is--color-profiline" href="<?php echo get_permalink( $up_sell_product->get_id() ); ?>">
                        <div class="snx-product-box__wrapper">
                          <div class="snx-product-box__image">
                            <picture>
                              <source
                                media="(max-width: 479px)"
                                srcset="
                                  <?php echo $img_brp_0[0]; ?> 1x
                                  <?php if (isset($img_brp_0_2x[0])) : ?>
                                  , <?php echo $img_brp_0_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 480px) and (max-width: 767px)"
                                srcset="
                                  <?php echo $img_brp_1[0]; ?> 1x
                                  <?php if (isset($img_brp_1_2x[0])) : ?>
                                  , <?php echo $img_brp_1_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 768px) and (max-width: 991px)"
                                srcset="
                                  <?php echo $img_brp_2[0]; ?> 1x
                                  <?php if (isset($img_brp_2_2x[0])) : ?>
                                  , <?php echo $img_brp_2_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 992px) and (max-width: 1199px)"
                                srcset="
                                  <?php echo $img_brp_3[0]; ?> 1x
                                  <?php if (isset($img_brp_3_2x[0])) : ?>
                                  , <?php echo $img_brp_3_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 1200px) and (max-width: 1399px)"
                                srcset="
                                  <?php echo $img_brp_4[0]; ?> 1x
                                  <?php if (isset($img_brp_4_2x[0])) : ?>
                                  , <?php echo $img_brp_4_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              
                              <img
                                src="<?php echo $img_full[0]; ?>"
                              />
                            </picture>
                          </div>
                          <div class="snx-product-box__detail">
                            <!-- <div class="snx-badge snx-is--color-brand-secondary">
                              <?php // echo strip_tags(wc_get_product_category_list($product->get_id())); ?>
                            </div> -->
                            <div class="snx-product-box__title"><?php echo $up_sell_product->get_name(); ?></div>
                          </div>
                        </div>
                      </a>
                    </div>
                  <?php endforeach; ?>
            
                </div>
              </div>


              <ul class="slick-dots" data-glide-el="controls[nav]">
                <?php foreach ($up_sell_ids as $index=>$upsell_id) : ?>
                  <li data-glide-dir="=<?php echo $index; ?>">
                    <button type="button">
                      <?php echo $index; ?>
                    </button>
                  </li>
                <?php endforeach; ?>
              </ul>

              <button class="slick-next slick-arrow" aria-label="Next" type="button" aria-disabled="false" data-glide-dir=">">Next</button>
              <button class="slick-prev slick-arrow" aria-label="Previous" type="button" aria-disabled="true" data-glide-dir="<">Previous</button>

            </div>
          </div>
        </div>

      </div>
    </section>

  <?php endif; ?>

  <?php
    $cross_sell_ids = $product->get_cross_sell_ids();
    if (!empty($cross_sell_ids) && check_products_are_not_all_empty($cross_sell_ids)) :
  ?>

    <section class="snx-page-section">
      <div class="snx-page-section__header">
        <h2 class="snx-page-section__headline">
          <?php echo __('Accessories', 'sonax'); ?>
        </h2>
      </div>

      <div class="snx-page-section__body">
        <div class="snx-slider snx-slider--slider-product">
          <div class="snx-slider__body">
            <div class="snx-slider__container" data-glide-el="controls">
              
              <div class="snx-slider__track-wrapper" data-glide-el="track">
                <div class="snx-slider__track" >

                  <?php 
                    foreach($cross_sell_ids as $id) :
                    $cross_sell_product = wc_get_product($id);

                    if (!$cross_sell_product) {
                      continue;
                    }

                    $img_brp_0 = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '293x195');
                    $img_brp_0_2x = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '600x400');
                    
                    $img_brp_1 = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '293x195');
                    $img_brp_1_2x = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '600x400');
                    
                    $img_brp_2 = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '375x250');
                    $img_brp_2_2x = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '750x500');
                    
                    $img_brp_3 = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '293x195');
                    $img_brp_3_2x = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '600x400');
                    
                    $img_brp_4 = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '293x195');
                    $img_brp_4_2x = wp_get_attachment_image_src($cross_sell_product->get_image_id(), '600x400');
                  
                    $img_full = wp_get_attachment_image_src($cross_sell_product->get_image_id(), 'full');
                  ?>
                  
                    <div class="snx-slider__slide">
                      <a class="snx-product-box snx-is--color-profiline" href="<?php echo get_permalink( $cross_sell_product->get_id() ); ?>">
                        <div class="snx-product-box__wrapper">
                          <div class="snx-product-box__image">
                            <picture>
                              <source
                                media="(max-width: 479px)"
                                srcset="
                                  <?php echo $img_brp_0[0]; ?> 1x
                                  <?php if (isset($img_brp_0_2x[0])) : ?>
                                  , <?php echo $img_brp_0_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 480px) and (max-width: 767px)"
                                srcset="
                                  <?php echo $img_brp_1[0]; ?> 1x
                                  <?php if (isset($img_brp_1_2x[0])) : ?>
                                  , <?php echo $img_brp_1_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 768px) and (max-width: 991px)"
                                srcset="
                                  <?php echo $img_brp_2[0]; ?> 1x
                                  <?php if (isset($img_brp_2_2x[0])) : ?>
                                  , <?php echo $img_brp_2_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 992px) and (max-width: 1199px)"
                                srcset="
                                  <?php echo $img_brp_3[0]; ?> 1x
                                  <?php if (isset($img_brp_3_2x[0])) : ?>
                                  , <?php echo $img_brp_3_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              <source
                                media="(min-width: 1200px) and (max-width: 1399px)"
                                srcset="
                                  <?php echo $img_brp_4[0]; ?> 1x
                                  <?php if (isset($img_brp_4_2x[0])) : ?>
                                  , <?php echo $img_brp_4_2x[0]; ?> 2x
                                  <?php endif; ?>
                                "
                              />
                              
                              <img
                                src="<?php echo $img_full[0]; ?>"
                              />
                            </picture>
                          </div>
                          <div class="snx-product-box__detail">
                            <!-- <div class="snx-badge snx-is--color-brand-secondary">
                              <?php // echo strip_tags(wc_get_product_category_list($product->get_id())); ?>
                            </div> -->
                            <div class="snx-product-box__title"><?php echo $cross_sell_product->get_name(); ?></div>
                          </div>
                        </div>
                      </a>
                    </div>
                  <?php endforeach; ?>

                </div> 
              </div>

              <ul class="slick-dots" data-glide-el="controls[nav]">
                <?php foreach ($cross_sell_ids as $index=>$cross_sell_id) : ?>
                  <li data-glide-dir="=<?php echo $index; ?>">
                    <button type="button">
                      <?php echo $index; ?>
                    </button>
                  </li>
                <?php endforeach; ?>
              </ul>

              <button class="slick-next slick-arrow" aria-label="Next" type="button" aria-disabled="false" data-glide-dir=">">Next</button>
              <button class="slick-prev slick-arrow" aria-label="Previous" type="button" aria-disabled="true" data-glide-dir="<">Previous</button>

            </div>
          </div>
        </div>

      </div>
    </section>

  <?php endif; ?>

</div>

<?php
  $locations = query_posts(array( 'post_type' => 'location', 'posts_per_page' => 100 ,'taxonomy_name'=>'reseller'));
?>

<?php if ($render_locations || !!$check_has_product_webshops) : ?>


  <div class="snx-modal" id="buySelection" role="dialog" aria-hidden="true">
    <div class="snx-modal__wrapper">
      <div class="snx-modal__header snx-modal__header--boxed">
        <div class="snx-modal__header-wrapper">
          <div class="snx-modal__header-image">
            <img lazy src="<?php echo $main_img_brp_0[0]; ?>" />
          </div>
          <div class="snx-modal__header-details">
            <span class="snx-modal__header-details-badge"><?php echo __('SKU:', 'sonax') ?>&nbsp;<?php echo $product->get_sku(); ?></span>
            <span class="snx-modal__header-details-title"><?php echo $product->get_name(); ?></span>
          </div>
        </div>
      </div>
      <div class="snx-modal__body">
        <div class="snx-modal__body-wrapper">
          <div class="snx-modal__item">
            <div class="snx-modal__item-wrapper">
              <div class="snx-tab">
                <?php if (!!$check_has_product_webshops) : ?>
                  <input type="radio" class="snx-tab__select" id="item-1" name="tab-1" checked="">
                <?php endif; ?>
                <?php if ($render_locations) : ?>
                  <input type="radio" class="snx-tab__select" id="item-2" name="tab-1" <?php if (!$check_has_product_webshops) : ?>checked=""<?php endif; ?>>
                <?php endif; ?>
                <nav class="snx-tab__header">
                  <?php if (!!$check_has_product_webshops) : ?>
                    <div class="snx-tab__header-item">
                      <label class="snx-tab__header-item-label" for="item-1">
                        <svg class="snx-icon snx-tab__header-item-label-icon" viewBox="0 0 32 32">
                          <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#shopping-cart-line"></use>
                        </svg>
                        <?php echo __('Buy Online'); ?>
                      </label>
                    </div>
                  <?php endif; ?>
                  <?php if ($render_locations) : ?>
                    <div class="snx-tab__header-item">
                      <label class="snx-tab__header-item-label" for="item-2">
                        <svg class="snx-icon snx-tab__header-item-label-icon" viewBox="0 0 32 32">
                          <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#store-2-line"></use>
                        </svg>
                        <?php echo __('Find Store'); ?>
                      </label>
                    </div>
                  <?php endif; ?>
                </nav>
                <figure class="snx-tab__body">
                  <?php if (!!$check_has_product_webshops) : ?>
                    <div class="snx-tab__item" data-tab-id="item-1">
                      <div class="snx-tab__item-content">
                        <div class="snx-list-logo snx-list-logo--boxed">
                          <div class="snx-list-logo__body">
                            <?php
                              foreach($product_webshops as $product_webshop) :
                                
                              $shop_logo_object = get_field('logo', $product_webshop['webshop']->ID);
                              $shop_logo_thumbnail = wp_get_attachment_image_src($shop_logo_object['id'], '293x195');
                              

                              $shop_title = $product_webshop['webshop']->post_title;
                              $shop_href = $product_webshop['webshop_product_link'];
                            ?>
                              <a class="snx-list-logo__item" href="<?php echo $shop_href; ?>" target="_blank">
                                <div class="snx-list-logo__item-image">
                                  <picture>
                                    <img src="<?php echo $shop_logo_thumbnail[0]; ?>">
                                  </picture>
                                </div>
                                <div class="snx-list-logo__item-name">
                                  <span class="snx-list-logo__item-name-label"><?php echo $shop_title ?></span>
                                </div>
                                <span class="snx-list-logo__item-action" >
                                  <svg class="snx-icon snx-list-logo__item-action-icon" viewBox="0 0 32 32">
                                    <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#shopping-cart-line"></use>
                                  </svg>
                                  <span class="snx-list-logo__item-action-label"><?php echo __('Buy Now', 'sonax'); ?></span>
                                </span>
                              </a>
                            <?php endforeach; ?>
                          </div>
                        </div>
                      </div>
                    </div>
                  <?php endif; ?>
                  <?php if ($render_locations) : ?>
                    <div class="snx-tab__item" data-tab-id="item-2">
                      <div class="snx-tab__item-content">

                        <?php include get_template_directory() . '/inc/locations-frontend.php'; ?>
                      </div>
                    </div>
                  <?php endif; ?>
                </figure>
              </div>
            </div>
          </div>
        </div>
      </div>
      <button class="snx-modal__toggle" data-modal-target="#buySelection">
        <svg class="snx-modal__toggle-asset" viewBox="0 0 32 32">
          <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_cross"></use>
        </svg>
      </button>
    </div>
  </div>

<?php endif; ?>

<div class="snx-modal snx-modal--fullscreen" id="productImages" role="dialog" aria-hidden="true">
    <div class="snx-modal__wrapper">
      <div class="snx-modal__body">
        <div class="snx-modal__body-wrapper">
          <div class="snx-modal__item">
            <div class="snx-modal__item-wrapper">
              <div class="snx-product-gallery">
                <div class="snx-product-gallery__header">
                  <div class="snx-product-gallery__header-title">
                    <span class="snx-product-gallery__header-title-label"><?php echo $product->get_name(); ?></span>
                  </div>
                  <div class="snx-product-gallery__header-sku">
                    <span class="snx-product-gallery__header-sku-label"><?php echo __('SKU:', 'sonax') ?>&nbsp;<?php echo $product->get_sku(); ?></span>
                  </div>
                </div>
                <div class="snx-product-gallery__body">
                  <div class="snx-product-gallery__body-gallery">
                    <div class="snx-slider snx-slider--slider-gallery-modal">
                      <div class="snx-slider__body">
                        <div class="snx-slider__container">
                          <div class="snx-slider__track-wrapper" data-glide-el="track">
                            <div class="snx-slider__track">
                          
                              <!-- Modal gallery items, repeat for each gallery item -->

                              <div class="snx-slider__slide">
                                <picture>
                                  <source
                                    media="(max-width: 479px)"
                                    srcset="
                                      <?php echo $main_img_brp_0[0]; ?> 1x
                                      <?php if (isset($main_img_brp_0_2x[0])) : ?>
                                      , <?php echo $main_img_brp_0_2x[0]; ?> 2x
                                      <?php endif; ?>
                                    "
                                  />
                                  <source
                                    media="(min-width: 480px) and (max-width: 767px)"
                                    srcset="
                                      <?php echo $main_img_brp_1[0]; ?> 1x
                                      <?php if (isset($main_img_brp_1_2x[0])) : ?>
                                      , <?php echo $main_img_brp_1_2x[0]; ?> 2x
                                      <?php endif; ?>
                                    "
                                  />
                                  <source
                                    media="(min-width: 768px) and (max-width: 991px)"
                                    srcset="
                                      <?php echo $main_img_brp_2[0]; ?> 1x
                                      <?php if (isset($main_img_brp_2_2x[0])) : ?>
                                      , <?php echo $main_img_brp_2_2x[0]; ?> 2x
                                      <?php endif; ?>
                                    "
                                  />
                                  <source
                                    media="(min-width: 992px) and (max-width: 1199px)"
                                    srcset="
                                      <?php echo $main_img_brp_3[0]; ?> 1x
                                      <?php if (isset($main_img_brp_3_2x[0])) : ?>
                                      , <?php echo $main_img_brp_3_2x[0]; ?> 2x
                                      <?php endif; ?>
                                    "
                                  />
                                  <source
                                    media="(min-width: 1200px) and (max-width: 1399px)"
                                    srcset="
                                      <?php echo $main_img_brp_4[0]; ?> 1x
                                      <?php if (isset($main_img_brp_4_2x[0])) : ?>
                                      , <?php echo $main_img_brp_4_2x[0]; ?> 2x
                                      <?php endif; ?>
                                    "
                                  />
                                  <source
                                    media="(min-width: 1400px)"
                                    srcset="
                                      <?php echo $main_img_brp_5[0]; ?> 1x
                                      <?php if (isset($main_img_brp_5_2x[0])) : ?>
                                      , <?php echo $main_img_brp_5_2x[0]; ?> 2x
                                      <?php endif; ?>
                                    "
                                  />
                                  <img
                                    src="<?php echo $main_img_full[0]; ?>"
                                  />
                                </picture>
                              </div>

                              <?php foreach ($gallery_attachment_ids as $gallery_attachment_id) : ?>
                                <?php
                                  $gallery_img_brp_0 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                                  $gallery_img_brp_0_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                                  $gallery_img_brp_1 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                                  $gallery_img_brp_1_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                                  $gallery_img_brp_2 = wp_get_attachment_image_src($gallery_attachment_id, '375x250');
                                  $gallery_img_brp_2_2x = wp_get_attachment_image_src($gallery_attachment_id, '750x500');

                                  $gallery_img_brp_3 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                                  $gallery_img_brp_3_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                                  $gallery_img_brp_4 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                                  $gallery_img_brp_4_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                                  $gallery_img_full = wp_get_attachment_image_src($gallery_attachment_id, 'full');  
                                ?>

                                <div class="snx-slider__slide">
                                  <picture>
                                    <source
                                      media="(max-width: 479px)"
                                      srcset="
                                        <?php echo $gallery_img_brp_0[0]; ?> 1x
                                        <?php if (isset($gallery_img_brp_0_2x[0])) : ?>
                                        , <?php echo $gallery_img_brp_0_2x[0]; ?> 2x
                                        <?php endif; ?>
                                      "
                                    />
                                    <source
                                      media="(min-width: 480px) and (max-width: 767px)"
                                      srcset="
                                        <?php echo $gallery_img_brp_1[0]; ?> 1x
                                        <?php if (isset($gallery_img_brp_1_2x[0])) : ?>
                                        , <?php echo $gallery_img_brp_1_2x[0]; ?> 2x
                                        <?php endif; ?>
                                      "
                                    />
                                    <source
                                      media="(min-width: 768px) and (max-width: 991px)"
                                      srcset="
                                        <?php echo $gallery_img_brp_2[0]; ?> 1x
                                        <?php if (isset($gallery_img_brp_2_2x[0])) : ?>
                                        , <?php echo $gallery_img_brp_2_2x[0]; ?> 2x
                                        <?php endif; ?>
                                      "
                                    />
                                    <source
                                      media="(min-width: 992px) and (max-width: 1199px)"
                                      srcset="
                                        <?php echo $gallery_img_brp_3[0]; ?> 1x
                                        <?php if (isset($gallery_img_brp_3_2x[0])) : ?>
                                        , <?php echo $gallery_img_brp_3_2x[0]; ?> 2x
                                        <?php endif; ?>
                                      "
                                    />
                                    <source
                                      media="(min-width: 1200px) and (max-width: 1399px)"
                                      srcset="
                                        <?php echo $gallery_img_brp_4[0]; ?> 1x
                                        <?php if (isset($gallery_img_brp_4_2x[0])) : ?>
                                        , <?php echo $gallery_img_brp_4_2x[0]; ?> 2x
                                        <?php endif; ?>
                                      "
                                    />
                                    
                                    <img
                                      src="<?php echo $gallery_img_full[0]; ?>"
                                    />
                                  </picture>
                                </div>

                              <?php endforeach; ?>
                          
                            </div>
                          </div>
                        </div>
                        <style>
                          .snx-slider .slick-dots {
                            display: flex !important;
                          }
                        </style>
                      </div>
                    </div>
                  </div>
                </div>
                <aside class="snx-product-gallery__aside">
                  <div class="snx-product-gallery__aside-thumbnails">
                    <!-- Modal gallery thumbnail items, repeat for each gallery item -->
                    <div class="snx-product-gallery__aside-thumbnails-item">
                      <div class="snx-product-gallery__aside-thumbnails-item-asset">
                        <picture>
                          <source
                            media="(min-width: 320px)"
                            srcset="
                              <?php echo $main_img_brp_0[0]; ?>
                              <?php if (isset($main_img_brp_0_2x[0])) : ?>
                              , <?php echo $main_img_brp_0_2x[0]; ?>
                              <?php endif; ?>
                            "
                          />
                          <img
                            src="<?php echo $main_img_full[0]; ?>"
                          />
                        </picture>
                      </div>
                    </div>

                    <?php foreach ($gallery_attachment_ids as $gallery_attachment_id) : ?>
                      <?php
                        $gallery_img_brp_0 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                        $gallery_img_brp_0_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                        $gallery_img_brp_1 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                        $gallery_img_brp_1_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                        $gallery_img_brp_2 = wp_get_attachment_image_src($gallery_attachment_id, '375x250');
                        $gallery_img_brp_2_2x = wp_get_attachment_image_src($gallery_attachment_id, '750x500');

                        $gallery_img_brp_3 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                        $gallery_img_brp_3_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                        $gallery_img_brp_4 = wp_get_attachment_image_src($gallery_attachment_id, '293x195');
                        $gallery_img_brp_4_2x = wp_get_attachment_image_src($gallery_attachment_id, '600x400');

                        $gallery_img_full = wp_get_attachment_image_src($gallery_attachment_id, 'full');  
                      ?>

                      <div class="snx-product-gallery__aside-thumbnails-item">
                        <div class="snx-product-gallery__aside-thumbnails-item-asset">
                          <picture>
                            <source
                              media="(min-width: 320px)"
                              srcset="
                                <?php echo $gallery_img_brp_0[0]; ?> 1x
                                <?php if (isset($gallery_img_brp_0_2x[0])) : ?>
                                , <?php echo $gallery_img_brp_0_2x[0]; ?> 2x
                                <?php endif; ?>
                              "
                            />
                            <img
                              src="<?php echo $gallery_img_full[0]; ?>"
                            />
                          </picture>
                        </div>
                      </div>

                    <?php endforeach; ?>
                    

                  </div>
                </aside>
              </div>
            </div>
          </div>
        </div>
      </div>
      <button class="snx-modal__toggle" data-modal-target="#productImages">
        <svg class="snx-modal__toggle-asset" viewBox="0 0 32 32">
          <use xlink:href="<?php echo get_template_directory_uri(); ?>/assets/sprite.svg#snx_cross"></use>
        </svg>
      </button>
    </div>
  </div>

<?php get_footer(); ?>
